@@ -1,7 +1,10 @@
 import os
+
 import numpy as np
+
 import theano
-import theano.tensor as T
+import theano.tensor as tt
+
 
 floatX = "float32"
 
@@ -17,18 +20,18 @@ def test_graph_opt_caching():
     default = theano.config.cache_optimizations
     try:
         theano.config.cache_optimizations = True
-        a = T.fmatrix("a")
-        b = T.fmatrix("b")
+        a = tt.fmatrix("a")
+        b = tt.fmatrix("b")
         c = theano.shared(np.ones((10, 10), dtype=floatX))
         d = theano.shared(np.ones((10, 10), dtype=floatX))
-        e = T.sum(T.sum(T.sum(a ** 2 + b) + c) + d)
+        e = tt.sum(tt.sum(tt.sum(a ** 2 + b) + c) + d)
         f1 = theano.function([a, b], e, mode=mode)
 
-        m = T.fmatrix("x1")
-        n = T.fmatrix("x2")
+        m = tt.fmatrix("x1")
+        n = tt.fmatrix("x2")
         p = theano.shared(np.ones((10, 10), dtype=floatX))
         q = theano.shared(np.ones((10, 10), dtype=floatX))
-        j = T.sum(T.sum(T.sum(m ** 2 + n) + p) + q)
+        j = tt.sum(tt.sum(tt.sum(m ** 2 + n) + p) + q)
         f2 = theano.function([m, n], j, mode=mode)
 
         in1 = np.ones((10, 10), dtype=floatX)
