@@ -1,25 +1,27 @@
-from theano.gof.type import Type
-from theano.gof.graph import Variable, Apply, Constant
+import theano.tensor as tt
+from theano.gof.fg import FunctionGraph
+from theano.gof.graph import Apply, Constant, Variable
 from theano.gof.op import Op
 from theano.gof.opt import (
+    EquilibriumOptimizer,
+    MergeOptimizer,
     OpKeyOptimizer,
+    OpSub,
     PatternSub,
     TopoOptimizer,
-    OpSub,
-    MergeOptimizer,
     config,
-    theano,
-    EquilibriumOptimizer,
     logging,
     pre_constant_merge,
     pre_greedy_local_optimizer,
+    theano,
 )
-from theano.gof.fg import FunctionGraph
-
-from theano import tensor as T
+from theano.gof.type import Type
+from theano.tensor.opt import constant_folding
+from theano.tensor.subtensor import AdvancedSubtensor
+from theano.tensor.type_other import MakeSlice, SliceConstant, slicetype
 
 
-def as_variable(x):
+def is_variable(x):
     if not isinstance(x, Variable):
         raise TypeError("not a Variable", x)
     return x
@@ -49,7 +51,7 @@ class MyOp(Op):
         self.x = x
 
     def make_node(self, *inputs):
-        inputs = list(map(as_variable, inputs))
+        inputs = list(map(is_variable, inputs))
         for input in inputs:
             if not isinstance(input.type, MyType):
                 raise Exception("Error 1")
@@ -385,9 +387,9 @@ class TestMergeOptimizer:
 
     def est_one_assert_merge(self):
         # Merge two nodes, one has assert, the other not.
-        x1 = T.matrix("x1")
-        x2 = T.matrix("x2")
-        e = T.dot(x1, x2) + T.dot(T.opt.assert_op(x1, (x1 > x2).all()), x2)
+        x1 = tt.matrix("x1")
+        x2 = tt.matrix("x2")
+        e = tt.dot(x1, x2) + tt.dot(tt.opt.assert_op(x1, (x1 > x2).all()), x2)
         g = FunctionGraph([x1, x2], [e])
         MergeOptimizer().optimize(g)
         strg = theano.printing.debugprint(g, file="str")
@@ -407,10 +409,10 @@ class TestMergeOptimizer:
     def test_both_assert_merge_identical(self):
         # Merge two nodes, both have assert on the same node
         # with the same conditions.
-        x1 = T.matrix("x1")
-        x2 = T.matrix("x2")
-        e = T.dot(T.opt.assert_op(x1, (x1 > x2).all()), x2) + T.dot(
-            T.opt.assert_op(x1, (x1 > x2).all()), x2
+        x1 = tt.matrix("x1")
+        x2 = tt.matrix("x2")
+        e = tt.dot(tt.opt.assert_op(x1, (x1 > x2).all()), x2) + tt.dot(
+            tt.opt.assert_op(x1, (x1 > x2).all()), x2
         )
         g = FunctionGraph([x1, x2], [e])
         MergeOptimizer().optimize(g)
@@ -432,11 +434,11 @@ class TestMergeOptimizer:
     def est_both_assert_merge_1(self):
         # Merge two nodes, both have assert on the same node
         # with different conditions.
-        x1 = T.matrix("x1")
-        x2 = T.matrix("x2")
-        x3 = T.matrix("x3")
-        e = T.dot(T.opt.assert_op(x1, (x1 > x3).all()), x2) + T.dot(
-            T.opt.assert_op(x1, (x1 > x2).all()), x2
+        x1 = tt.matrix("x1")
+        x2 = tt.matrix("x2")
+        x3 = tt.matrix("x3")
+        e = tt.dot(tt.opt.assert_op(x1, (x1 > x3).all()), x2) + tt.dot(
+            tt.opt.assert_op(x1, (x1 > x2).all()), x2
         )
         g = FunctionGraph([x1, x2, x3], [e])
         MergeOptimizer().optimize(g)
@@ -476,11 +478,11 @@ class TestMergeOptimizer:
 
     def est_both_assert_merge_2(self):
         # Merge two nodes, both have assert on different node
-        x1 = T.matrix("x1")
-        x2 = T.matrix("x2")
-        x3 = T.matrix("x3")
-        e = T.dot(T.opt.assert_op(x1, (x1 > x3).all()), x2) + T.dot(
-            x1, T.opt.assert_op(x2, (x2 > x3).all())
+        x1 = tt.matrix("x1")
+        x2 = tt.matrix("x2")
+        x3 = tt.matrix("x3")
+        e = tt.dot(tt.opt.assert_op(x1, (x1 > x3).all()), x2) + tt.dot(
+            x1, tt.opt.assert_op(x2, (x2 > x3).all())
         )
         g = FunctionGraph([x1, x2, x3], [e])
         MergeOptimizer().optimize(g)
@@ -506,11 +508,11 @@ class TestMergeOptimizer:
 
     def est_both_assert_merge_2_reverse(self):
         # Test case "test_both_assert_merge_2" but in reverse order
-        x1 = T.matrix("x1")
-        x2 = T.matrix("x2")
-        x3 = T.matrix("x3")
-        e = T.dot(x1, T.opt.assert_op(x2, (x2 > x3).all())) + T.dot(
-            T.opt.assert_op(x1, (x1 > x3).all()), x2
+        x1 = tt.matrix("x1")
+        x2 = tt.matrix("x2")
+        x3 = tt.matrix("x3")
+        e = tt.dot(x1, tt.opt.assert_op(x2, (x2 > x3).all())) + tt.dot(
+            tt.opt.assert_op(x1, (x1 > x3).all()), x2
         )
         g = FunctionGraph([x1, x2, x3], [e])
         MergeOptimizer().optimize(g)
@@ -546,7 +548,7 @@ class TestMergeOptimizer:
         assert len(no_input_ops) == 2, fg.apply_nodes
 
 
-class TestEquilibrium(object):
+class TestEquilibrium:
     def test_1(self):
         x, y, z = map(MyVariable, "xyz")
         e = op3(op4(x, y))
@@ -610,18 +612,14 @@ class TestEquilibrium(object):
 
 
 def test_pre_constant_merge_slice():
-    ms = theano.tensor.type_other.MakeSlice()(1)
+    ms = MakeSlice()(1)
     pre_constant_merge([ms])
-    const_slice = theano.tensor.type_other.SliceConstant(
-        type=theano.tensor.type_other.slicetype, data=slice(1, None, 2)
-    )
-    adv = theano.tensor.subtensor.AdvancedSubtensor()(
-        theano.tensor.matrix(), [2, 3], const_slice
-    )
+    const_slice = SliceConstant(type=slicetype, data=slice(1, None, 2))
+    adv = AdvancedSubtensor()(tt.matrix(), [2, 3], const_slice)
     pre_constant_merge(adv)
 
-    cst = pre_greedy_local_optimizer([theano.tensor.opt.constant_folding], ms)
-    assert isinstance(cst, theano.tensor.type_other.SliceConstant)
+    cst = pre_greedy_local_optimizer([constant_folding], ms)
+    assert isinstance(cst, SliceConstant)
 
     # Make sure constant of slice signature is hashable.
     hash(cst.signature())
