@@ -1,10 +1,10 @@
-import pytest
-
 import numpy as np
+import pytest
 
 import theano
 import theano.tensor as tt
 
+
 jax = pytest.importorskip("jax")
 
 from functools import partial  # noqa: E402
@@ -21,17 +21,39 @@ def set_theano_flags():
 def compare_jax_and_py(
     fgraph,
     inputs,
-    assert_fn=partial(np.testing.assert_allclose, rtol=1e-4),
-    simplify=False,
+    assert_fn=None,
     must_be_device_array=True,
 ):
-    if not simplify:
-        opts = theano.gof.Query(include=[None], exclude=["cxx_only", "BlasOpt"])
-        jax_mode = theano.compile.mode.Mode(theano.sandbox.jax_linker.JAXLinker(), opts)
-        py_mode = theano.compile.Mode("py", opts)
-    else:
-        py_mode = theano.compile.Mode(linker="py")
-        jax_mode = "JAX"
+    """Function to compare python graph output and jax compiled output for testing equality
+
+    In the tests below computational graphs are defined in Theano. These graphs are then passed to
+    this function which then compiles the graphs in both jax and python, runs the calculation
+    in both and checks if the results are the same
+
+    Parameters
+    ----------
+    fgraph: theano.gof.FunctionGraph
+        Theano function Graph object
+    inputs: iter
+        Inputs for function graph
+    assert_fn: func, opt
+        Assert function used to check for equality between python and jax. If not
+        provided uses np.testing.assert_allclose
+    must_be_device_array: Bool
+        Checks for instance of jax.interpreters.xla.DeviceArray. For testing purposes
+        if this device array is found it indicates if the result was computed by jax
+
+    Returns
+    -------
+    jax_res
+
+    """
+    if assert_fn is None:
+        assert_fn = partial(np.testing.assert_allclose, rtol=1e-4)
+
+    opts = theano.gof.Query(include=[None], exclude=["cxx_only", "BlasOpt"])
+    jax_mode = theano.compile.mode.Mode(theano.sandbox.jax_linker.JAXLinker(), opts)
+    py_mode = theano.compile.Mode("py", opts)
 
     theano_jax_fn = theano.function(fgraph.inputs, fgraph.outputs, mode=jax_mode)
     jax_res = theano_jax_fn(*inputs)
@@ -219,6 +241,14 @@ def test_jax_basic():
     )
 
 
+def test_jax_eye():
+    """Tests jaxification of the Eye operator"""
+    out = tt.eye(3)
+    out_fg = theano.gof.FunctionGraph([], [out])
+
+    compare_jax_and_py(out_fg, [])
+
+
 def test_jax_basic_multiout():
 
     np.random.seed(213234)
@@ -308,7 +338,7 @@ def test_jax_scan():
     test_input_vals = [np.array(10.0).astype(tt.config.floatX)]
     (jax_res,) = compare_jax_and_py(out_fg, test_input_vals)
 
-    assert False
+    raise AssertionError()
 
 
 def test_jax_Subtensors():
