@@ -1,23 +1,22 @@
-import pytest
-import six.moves.builtins as builtins
-import numpy as np
-import theano
-import theano.tensor as tensor
-
+import builtins
 from itertools import product
 
+import numpy as np
+import pytest
+
+import theano
+import theano.tensor as tensor
+from tests import unittest_tools as utt
+from theano import function
 from theano.tensor.signal.pool import (
+    AveragePoolGrad,
+    DownsampleFactorMaxGradGrad,
+    MaxPoolGrad,
     Pool,
+    max_pool_2d_same_size,
     pool_2d,
     pool_3d,
-    MaxPoolGrad,
-    AveragePoolGrad,
-    max_pool_2d_same_size,
-    DownsampleFactorMaxGradGrad,
 )
-from theano import function
-
-from tests import unittest_tools as utt
 
 
 class TestDownsampleFactorMax(utt.InferShapeTester):
@@ -466,7 +465,7 @@ class TestDownsampleFactorMax(utt.InferShapeTester):
             )
             assert (
                 numpy_output_val.shape == outputshp
-            ), "outshape is %s, calculated shape is %s" % (
+            ), "outshape is {}, calculated shape is {}".format(
                 outputshp,
                 numpy_output_val.shape,
             )
@@ -517,7 +516,7 @@ class TestDownsampleFactorMax(utt.InferShapeTester):
                 )
                 assert (
                     numpy_output_val.shape == outputshp
-                ), "outshape is %s, calculated shape is %s" % (
+                ), "outshape is {}, calculated shape is {}".format(
                     outputshp,
                     numpy_output_val.shape,
                 )
