@@ -1,42 +1,39 @@
-import pytest
 import numpy as np
 import numpy.linalg
-import theano
-
-
+import pytest
 from numpy import inf
 from numpy.testing import assert_array_almost_equal
 
-from theano import tensor, function
+import theano
+from tests import unittest_tools as utt
+from theano import config, function, tensor
+from theano.configparser import change_flags
 from theano.tensor.basic import _allclose
-from theano import config
 from theano.tensor.nlinalg import (
-    MatrixInverse,
-    matrix_inverse,
-    pinv,
+    SVD,
     AllocDiag,
-    alloc_diag,
-    ExtractDiag,
-    extract_diag,
-    diag,
-    trace,
-    det,
     Eig,
+    ExtractDiag,
+    MatrixInverse,
+    TensorInv,
+    alloc_diag,
+    det,
+    diag,
     eig,
     eigh,
+    extract_diag,
     matrix_dot,
-    qr,
+    matrix_inverse,
     matrix_power,
     norm,
+    pinv,
+    qr,
     svd,
-    SVD,
-    TensorInv,
     tensorinv,
     tensorsolve,
+    trace,
 )
 
-from tests import unittest_tools as utt
-
 
 def test_pseudoinverse_correctness():
     rng = np.random.RandomState(utt.fetch_seed())
@@ -239,11 +236,8 @@ def test_inverse_singular():
     singular = np.array([[1, 0, 0]] + [[0, 1, 0]] * 2, dtype=theano.config.floatX)
     a = tensor.matrix()
     f = function([a], matrix_inverse(a))
-    try:
+    with pytest.raises(np.linalg.LinAlgError):
         f(singular)
-    except np.linalg.LinAlgError:
-        return
-    assert False
 
 
 def test_inverse_grad():
@@ -532,24 +526,30 @@ class TestLstsq:
             f([2, 1], [2, 1], [2, 1])
 
 
-class TestMatrix_power:
-    def test_numpy_compare(self):
-        rng = np.random.RandomState(utt.fetch_seed())
+class TestMatrixPower:
+    @change_flags(compute_test_value="raise")
+    @pytest.mark.parametrize("n", [-1, 0, 1, 2, 3, 4, 5, 11])
+    def test_numpy_compare(self, n):
+        a = np.array([[0.1231101, 0.72381381], [0.28748201, 0.43036511]]).astype(
+            theano.config.floatX
+        )
         A = tensor.matrix("A", dtype=theano.config.floatX)
-        Q = matrix_power(A, 3)
-        fn = function([A], [Q])
-        a = rng.rand(4, 4).astype(theano.config.floatX)
-
-        n_p = np.linalg.matrix_power(a, 3)
-        t_p = fn(a)
-        assert np.allclose(n_p, t_p)
+        A.tag.test_value = a
+        Q = matrix_power(A, n)
+        n_p = np.linalg.matrix_power(a, n)
+        assert np.allclose(n_p, Q.get_test_value())
 
     def test_non_square_matrix(self):
-        rng = np.random.RandomState(utt.fetch_seed())
         A = tensor.matrix("A", dtype=theano.config.floatX)
         Q = matrix_power(A, 3)
         f = function([A], [Q])
-        a = rng.rand(4, 3).astype(theano.config.floatX)
+        a = np.array(
+            [
+                [0.47497769, 0.81869379],
+                [0.74387558, 0.31780172],
+                [0.54381007, 0.28153101],
+            ]
+        ).astype(theano.config.floatX)
         with pytest.raises(ValueError):
             f(a)
 
