@@ -1,18 +1,14 @@
-import pytest
-
-import six
+from functools import update_wrapper
 
 import numpy as np
+import pytest
 
 import theano
 import theano.sparse
-
-from functools import update_wrapper
-
+from tests import unittest_tools as utt
 from theano import tensor
 from theano.misc.may_share_memory import may_share_memory
 
-from tests import unittest_tools as utt
 
 utt.seed_rng()
 
@@ -68,9 +64,6 @@ def makeSharedTester(
         pass
 
     class SharedTester:
-        # This is to allow setting __doc__ with python 2
-        if not six.PY3:
-            __metaclass__ = m
         shared_constructor = staticmethod(shared_constructor_)
         dtype = dtype_
         get_value_borrow_true_alias = get_value_borrow_true_alias_
@@ -431,7 +424,7 @@ def makeSharedTester(
             topo_cst = shape_constant_fct.maker.fgraph.toposort()
             if theano.config.mode != "FAST_COMPILE":
                 assert len(topo_cst) == 1
-                topo_cst[0].op == theano.compile.function_module.deep_copy_op
+                topo_cst[0].op == theano.compile.function.types.deep_copy_op
 
             # Test that we can take the grad.
             if theano.sparse.enable_sparse and isinstance(
@@ -540,7 +533,8 @@ def makeSharedTester(
             s = self.cast_value(s)
             s_shared = self.shared_constructor(s)
             f = theano.function(
-                [], updates=[(s_shared, theano.dot(a_shared, b_shared) + s_shared)]
+                [],
+                updates=[(s_shared, theano.tensor.dot(a_shared, b_shared) + s_shared)],
             )
             topo = f.maker.fgraph.toposort()
             f()
@@ -576,7 +570,9 @@ def makeSharedTester(
             f = theano.function(
                 [],
                 s_shared.shape,
-                updates=[(s_shared, theano.dot(a_shared, b_shared) + s_shared_specify)],
+                updates=[
+                    (s_shared, theano.tensor.dot(a_shared, b_shared) + s_shared_specify)
+                ],
             )
             topo = f.maker.fgraph.toposort()
             shp = f()
@@ -613,7 +609,9 @@ def makeSharedTester(
             f = theano.function(
                 [],
                 s_shared.shape,
-                updates=[(s_shared, theano.dot(a_shared, b_shared) + s_shared_specify)],
+                updates=[
+                    (s_shared, theano.tensor.dot(a_shared, b_shared) + s_shared_specify)
+                ],
             )
             topo = f.maker.fgraph.toposort()
             shp = f()
@@ -696,10 +694,10 @@ def makeSharedTester(
     internal_type_=np.ndarray,
     check_internal_type_=lambda a: isinstance(a, np.ndarray),
     theano_fct_=lambda a: a * 2,
-    ref_fct_=lambda a: np.asarray((a * 2)),
+    ref_fct_=lambda a: np.asarray(a * 2),
     cast_value_=np.asarray,
 )
-class TestSharedOptions(object):
+class TestSharedOptions:
     pass
 
 
