@@ -1,26 +1,25 @@
 import numpy as np
-
 import pytest
 
 import theano
+import theano.tensor as tt
 import theano.typed_list
-
-from theano import tensor as T, sparse
+from tests import unittest_tools as utt
+from theano import sparse
 from theano.tensor.type_other import SliceType
-from theano.typed_list.type import TypedListType
 from theano.typed_list.basic import (
-    GetItem,
-    Insert,
     Append,
+    Count,
     Extend,
+    GetItem,
+    Index,
+    Insert,
+    Length,
     Remove,
     Reverse,
-    Index,
-    Count,
-    Length,
     make_list,
 )
-from tests import unittest_tools as utt
+from theano.typed_list.type import TypedListType
 
 
 def rand_ranged_matrix(minimum, maximum, shape):
@@ -39,7 +38,7 @@ def random_lil(shape, dtype, nnz):
         idx = np.random.randint(1, huge + 1, size=2) % shape
         value = np.random.rand()
         # if dtype *int*, value will always be zeros!
-        if dtype in theano.tensor.integer_dtypes:
+        if dtype in tt.integer_dtypes:
             value = int(value * 100)
         # The call to tuple is needed as scipy 0.13.1 do not support
         # ndarray with length 2 as idx tuple.
@@ -54,14 +53,14 @@ class TestGetItem:
     def test_sanity_check_slice(self):
 
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         mySymbolicSlice = SliceType()()
 
         z = GetItem()(mySymbolicMatricesList, mySymbolicSlice)
 
-        assert not isinstance(z, T.TensorVariable)
+        assert not isinstance(z, tt.TensorVariable)
 
         f = theano.function([mySymbolicMatricesList, mySymbolicSlice], z)
 
@@ -72,10 +71,10 @@ class TestGetItem:
     def test_sanity_check_single(self):
 
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
-        mySymbolicScalar = T.scalar(dtype="int64")
+        mySymbolicScalar = tt.scalar(dtype="int64")
 
         z = GetItem()(mySymbolicMatricesList, mySymbolicScalar)
 
@@ -87,9 +86,9 @@ class TestGetItem:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        mySymbolicScalar = T.scalar(dtype="int64")
+        mySymbolicScalar = tt.scalar(dtype="int64")
 
         z = mySymbolicMatricesList[mySymbolicScalar]
 
@@ -107,16 +106,16 @@ class TestGetItem:
 
     def test_wrong_input(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        mySymbolicMatrix = T.matrix()
+        mySymbolicMatrix = tt.matrix()
 
         with pytest.raises(TypeError):
             GetItem()(mySymbolicMatricesList, mySymbolicMatrix)
 
     def test_constant_input(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = GetItem()(mySymbolicMatricesList, 0)
@@ -137,9 +136,9 @@ class TestGetItem:
 class TestAppend:
     def test_inplace(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = Append(True)(mySymbolicMatricesList, myMatrix)
 
@@ -153,9 +152,9 @@ class TestAppend:
 
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = Append()(mySymbolicMatricesList, myMatrix)
 
@@ -169,9 +168,9 @@ class TestAppend:
 
     def test_interfaces(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = mySymbolicMatricesList.append(myMatrix)
 
@@ -187,10 +186,10 @@ class TestAppend:
 class TestExtend:
     def test_inplace(self):
         mySymbolicMatricesList1 = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
         mySymbolicMatricesList2 = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Extend(True)(mySymbolicMatricesList1, mySymbolicMatricesList2)
@@ -207,10 +206,10 @@ class TestExtend:
 
     def test_sanity_check(self):
         mySymbolicMatricesList1 = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
         mySymbolicMatricesList2 = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Extend()(mySymbolicMatricesList1, mySymbolicMatricesList2)
@@ -225,10 +224,10 @@ class TestExtend:
 
     def test_interface(self):
         mySymbolicMatricesList1 = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
         mySymbolicMatricesList2 = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = mySymbolicMatricesList1.extend(mySymbolicMatricesList2)
@@ -245,10 +244,10 @@ class TestExtend:
 class TestInsert:
     def test_inplace(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
-        myScalar = T.scalar(dtype="int64")
+        myMatrix = tt.matrix()
+        myScalar = tt.scalar(dtype="int64")
 
         z = Insert(True)(mySymbolicMatricesList, myScalar, myMatrix)
 
@@ -264,10 +263,10 @@ class TestInsert:
 
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
-        myScalar = T.scalar(dtype="int64")
+        myMatrix = tt.matrix()
+        myScalar = tt.scalar(dtype="int64")
 
         z = Insert()(mySymbolicMatricesList, myScalar, myMatrix)
 
@@ -281,10 +280,10 @@ class TestInsert:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
-        myScalar = T.scalar(dtype="int64")
+        myMatrix = tt.matrix()
+        myScalar = tt.scalar(dtype="int64")
 
         z = mySymbolicMatricesList.insert(myScalar, myMatrix)
 
@@ -300,9 +299,9 @@ class TestInsert:
 class TestRemove:
     def test_inplace(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = Remove(True)(mySymbolicMatricesList, myMatrix)
 
@@ -316,9 +315,9 @@ class TestRemove:
 
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = Remove()(mySymbolicMatricesList, myMatrix)
 
@@ -332,9 +331,9 @@ class TestRemove:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = mySymbolicMatricesList.remove(myMatrix)
 
@@ -350,7 +349,7 @@ class TestRemove:
 class TestReverse:
     def test_inplace(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Reverse(True)(mySymbolicMatricesList)
@@ -365,7 +364,7 @@ class TestReverse:
 
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Reverse()(mySymbolicMatricesList)
@@ -380,7 +379,7 @@ class TestReverse:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = mySymbolicMatricesList.reverse()
@@ -397,9 +396,9 @@ class TestReverse:
 class TestIndex:
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = Index()(mySymbolicMatricesList, myMatrix)
 
@@ -413,9 +412,9 @@ class TestIndex:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = mySymbolicMatricesList.ind(myMatrix)
 
@@ -429,10 +428,10 @@ class TestIndex:
 
     def test_non_tensor_type(self):
         mySymbolicNestedMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False)), 1
+            tt.TensorType(theano.config.floatX, (False, False)), 1
         )()
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Index()(mySymbolicNestedMatricesList, mySymbolicMatricesList)
@@ -465,9 +464,9 @@ class TestIndex:
 class TestCount:
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = Count()(mySymbolicMatricesList, myMatrix)
 
@@ -481,9 +480,9 @@ class TestCount:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
-        myMatrix = T.matrix()
+        myMatrix = tt.matrix()
 
         z = mySymbolicMatricesList.count(myMatrix)
 
@@ -497,10 +496,10 @@ class TestCount:
 
     def test_non_tensor_type(self):
         mySymbolicNestedMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False)), 1
+            tt.TensorType(theano.config.floatX, (False, False)), 1
         )()
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Count()(mySymbolicNestedMatricesList, mySymbolicMatricesList)
@@ -533,7 +532,7 @@ class TestCount:
 class TestLength:
     def test_sanity_check(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
 
         z = Length()(mySymbolicMatricesList)
@@ -546,7 +545,7 @@ class TestLength:
 
     def test_interface(self):
         mySymbolicMatricesList = TypedListType(
-            T.TensorType(theano.config.floatX, (False, False))
+            tt.TensorType(theano.config.floatX, (False, False))
         )()
         z = mySymbolicMatricesList.__len__()
 
@@ -559,18 +558,18 @@ class TestLength:
 
 class TestMakeList:
     def test_wrong_shape(self):
-        a = T.vector()
-        b = T.matrix()
+        a = tt.vector()
+        b = tt.matrix()
 
         with pytest.raises(TypeError):
             make_list((a, b))
 
     def test_correct_answer(self):
-        a = T.matrix()
-        b = T.matrix()
+        a = tt.matrix()
+        b = tt.matrix()
 
-        x = T.tensor3()
-        y = T.tensor3()
+        x = tt.tensor3()
+        y = tt.tensor3()
 
         A = np.cast[theano.config.floatX](np.random.rand(5, 3))
         B = np.cast[theano.config.floatX](np.random.rand(7, 2))
