@@ -7,30 +7,28 @@ TODO: add support for IfElse Op, LazyLinker, PureOp, etc.
 
 
 import copy
-import sys
 import gc
 import logging
-from itertools import chain, product as itertools_product
-from theano.compat import izip
+import sys
+from io import StringIO
+from itertools import chain
+from itertools import product as itertools_product
 
 import numpy as np
 
 import theano
-from theano import gof, config
-from theano.compat import get_unbound_function
-from six import iteritems, itervalues
-from six.moves import StringIO, xrange
-from theano.gof import graph, utils, link, ops_with_inner_function
-from theano.gof.link import raise_with_op
-from theano.compile.function_module import (
-    FunctionMaker,
+from theano import change_flags, config, gof
+from theano.compile.function.types import (
     Function,
+    FunctionMaker,
     infer_reuse_pattern,
     std_fgraph,
 )
 from theano.compile.mode import Mode, register_mode
 from theano.compile.ops import OutputGuard, _output_guard
-from theano import change_flags
+from theano.gof import graph, link, ops_with_inner_function, utils
+from theano.gof.link import raise_with_op
+from theano.utils import get_unbound_function
 
 
 __docformat__ = "restructuredtext en"
@@ -39,7 +37,7 @@ _logger = logging.getLogger("theano.compile.debugmode")
 
 # Filter to avoid duplicating optimization warnings
 class NoDuplicateOptWarningFilter(logging.Filter):
-    prev_msgs = set([])
+    prev_msgs = set()
 
     def filter(self, record):
         msg = record.getMessage()
@@ -66,8 +64,6 @@ class DebugModeError(Exception):
 
     """
 
-    pass
-
 
 class BadThunkOutput(DebugModeError):
     """
@@ -101,7 +97,7 @@ class BadThunkOutput(DebugModeError):
     """
 
     def __init__(self, r, thunk1, val1, thunk2, val2, inputs_val=()):
-        super(BadThunkOutput, self).__init__()
+        super().__init__()
         self.r = r
         self.thunk1 = thunk1
         self.val1 = val1
@@ -155,10 +151,7 @@ class BadThunkOutput(DebugModeError):
         print("  thunk1  :", self.thunk1, file=sio)
         print("  thunk2  :", self.thunk2, file=sio)
 
-        # Don't import it at the top of the file to prevent circular import.
-        import theano.tests.unittest_tools as utt
-
-        print(utt.str_diagnostic(self.val1, self.val2, None, None), file=sio)
+        print(str_diagnostic(self.val1, self.val2, None, None), file=sio)
         ret = sio.getvalue()
         return ret
 
@@ -175,7 +168,7 @@ class BadDestroyMap(DebugModeError):
     """
 
     def __init__(self, node, idx, old_val, new_val, perform):
-        super(BadDestroyMap, self).__init__()
+        super().__init__()
         self.node = node
         self.idx = idx
         self.old_val = old_val
@@ -259,7 +252,7 @@ class BadViewMap(DebugModeError):
     def __init__(
         self, node, output_idx, out_storage, in_alias_idx=None, out_alias_idx=None
     ):
-        super(BadViewMap, self).__init__()
+        super().__init__()
         self.node = node
         self.output_idx = output_idx
         self.out_storage = out_storage
@@ -295,8 +288,6 @@ class StochasticOrder(DebugModeError):
 
     """
 
-    pass
-
 
 class InvalidValueError(DebugModeError):
     """
@@ -309,7 +300,7 @@ class InvalidValueError(DebugModeError):
     """
 
     def __init__(self, r, v=None, client_node=None, hint="none", specific_hint="none"):
-        super(InvalidValueError, self).__init__()
+        super().__init__()
         self.r = r
         self.v = v
         self.client_node = client_node
@@ -380,6 +371,71 @@ class InvalidValueError(DebugModeError):
 ########################
 
 
+def str_diagnostic(expected, value, rtol, atol):
+    """Return a pretty multiline string representating the cause
+    of the exception"""
+    sio = StringIO()
+
+    try:
+        ssio = StringIO()
+        print("           : shape, dtype, strides, min, max, n_inf, n_nan:", file=ssio)
+        print("  Expected :", end=" ", file=ssio)
+        print(expected.shape, end=" ", file=ssio)
+        print(expected.dtype, end=" ", file=ssio)
+        print(expected.strides, end=" ", file=ssio)
+        print(expected.min(), end=" ", file=ssio)
+        print(expected.max(), end=" ", file=ssio)
+        print(np.isinf(expected).sum(), end=" ", file=ssio)
+        print(np.isnan(expected).sum(), end=" ", file=ssio)
+        # only if all succeeds to we add anything to sio
+        print(ssio.getvalue(), file=sio)
+    except Exception:
+        pass
+    try:
+        ssio = StringIO()
+        print("  Value    :", end=" ", file=ssio)
+        print(value.shape, end=" ", file=ssio)
+        print(value.dtype, end=" ", file=ssio)
+        print(value.strides, end=" ", file=ssio)
+        print(value.min(), end=" ", file=ssio)
+        print(value.max(), end=" ", file=ssio)
+        print(np.isinf(value).sum(), end=" ", file=ssio)
+        print(np.isnan(value).sum(), end=" ", file=ssio)
+        # only if all succeeds to we add anything to sio
+        print(ssio.getvalue(), file=sio)
+    except Exception:
+        pass
+
+    print("  expected    :", expected, file=sio)
+    print("  value    :", value, file=sio)
+
+    try:
+        ov = np.asarray(expected)
+        nv = np.asarray(value)
+        ssio = StringIO()
+        absdiff = np.absolute(nv - ov)
+        print("  Max Abs Diff: ", np.max(absdiff), file=ssio)
+        print("  Mean Abs Diff: ", np.mean(absdiff), file=ssio)
+        print("  Median Abs Diff: ", np.median(absdiff), file=ssio)
+        print("  Std Abs Diff: ", np.std(absdiff), file=ssio)
+        reldiff = np.absolute(nv - ov) / np.absolute(ov)
+        print("  Max Rel Diff: ", np.max(reldiff), file=ssio)
+        print("  Mean Rel Diff: ", np.mean(reldiff), file=ssio)
+        print("  Median Rel Diff: ", np.median(reldiff), file=ssio)
+        print("  Std Rel Diff: ", np.std(reldiff), file=ssio)
+        # only if all succeeds to we add anything to sio
+        print(ssio.getvalue(), file=sio)
+    except Exception:
+        pass
+    atol_, rtol_ = theano.tensor.basic._get_atol_rtol(expected, value)
+    if rtol is not None:
+        rtol_ = rtol
+    if atol is not None:
+        atol_ = atol
+    print("  rtol, atol:", rtol_, atol_, file=sio)
+    return sio.getvalue()
+
+
 def char_from_number(number):
     """
     Converts number to string by rendering it in base 26 using
@@ -626,7 +682,9 @@ def debugprint(
                         new_prefix_child = prefix_child + "  "
 
                     if hasattr(i, "owner") and hasattr(i.owner, "op"):
-                        if isinstance(i.owner.op, theano.scan_module.scan_op.Scan):
+                        from theano.scan.op import Scan
+
+                        if isinstance(i.owner.op, Scan):
                             scan_ops.append(i)
 
                     debugprint(
@@ -658,7 +716,7 @@ def debugprint(
             else:
                 outer_id_str = get_id_str(outer_r)
             print(
-                "%s%s %s%s -> %s" % (prefix, r, id_str, type_str, outer_id_str),
+                "{}{} {}{} -> {}".format(prefix, r, id_str, type_str, outer_id_str),
                 file=file,
             )
         else:
@@ -667,7 +725,7 @@ def debugprint(
             if smap:
                 data = " " + str(smap.get(r, ""))
             id_str = get_id_str(r)
-            print("%s%s %s%s%s" % (prefix, r, id_str, type_str, data), file=file)
+            print("{}{} {}{}{}".format(prefix, r, id_str, type_str, data), file=file)
 
     return file
 
@@ -737,13 +795,13 @@ def _check_inputs(
     """
     destroyed_idx_list = []
     destroy_map = getattr(node.op, "destroy_map", {})
-    for o_pos, i_pos_list in iteritems(destroy_map):
+    for o_pos, i_pos_list in destroy_map.items():
         destroyed_idx_list.extend(i_pos_list)
     destroyed_res_list = [node.inputs[i] for i in destroyed_idx_list]
 
     actually_inplace_outputs = []
     dmap = getattr(node.op, "destroy_map", {})
-    for oo, ii in iteritems(dmap):
+    for oo, ii in dmap.items():
         var = node.outputs[oo]
         out_var = storage_map[var][0]
         in_var = storage_map[node.inputs[ii[0]]][0]
@@ -766,7 +824,7 @@ def _check_inputs(
                 )
 
     vmap = getattr(node.op, "view_map", {})
-    for oo, ii in iteritems(vmap):
+    for oo, ii in vmap.items():
         var = node.outputs[oo]
         out_var = storage_map[var][0]
         in_var = storage_map[node.inputs[ii[0]]][0]
@@ -864,7 +922,7 @@ def _check_viewmap(node, storage_map):
         # TODO: make sure this is correct
         # According to OB, duplicate inputs are rejected on build graph time
         # if they cause problems. So if they are here it should be ok.
-        for key, val in iteritems(good_alias):
+        for key, val in good_alias.items():
             bad_alias.pop(key, None)
         if bad_alias:
             raise BadViewMap(node, oi, outstorage, list(bad_alias.values()))
@@ -1013,16 +1071,16 @@ def _find_bad_optimizations1(order, reasons, r_vals):
     for i, node in enumerate(order):
         program_position[node] = i
         for new_r in node.outputs:
-            equivalence_sets.setdefault(new_r, set([new_r]))
+            equivalence_sets.setdefault(new_r, {new_r})
             for reason, r, old_graph_str, new_graph_str in reasons[new_r]:
-                equivalence_sets[new_r].update(equivalence_sets.setdefault(r, set([r])))
+                equivalence_sets[new_r].update(equivalence_sets.setdefault(r, {r}))
                 for er in equivalence_sets[r]:
                     equivalence_sets[er] = equivalence_sets[new_r]
 
     # identify equivalence sets that are broken
     equivalence_sets_broken = {}  # id(set) -> Bool
     there_is_a_problem = False
-    for r, r_equiv in iteritems(equivalence_sets):
+    for r, r_equiv in equivalence_sets.items():
         if id(r_equiv) not in equivalence_sets_broken:
             equivalence_sets_broken[id(r_equiv)] = False
             # loop over the variables in the set comparing them to be
@@ -1133,8 +1191,8 @@ def _get_preallocated_maps(
     """
 
     # To avoid circular imports
-    from theano.tensor import TensorType
     from theano.gpuarray import GpuArrayType
+    from theano.tensor import TensorType
 
     try:
         import pygpu
@@ -1373,7 +1431,7 @@ def _check_preallocated_output(
             fn_attr_name = ops_with_inner_function[type(node.op)]
             fn = getattr(node.op, fn_attr_name, None)
             if not fn or not hasattr(fn, "maker") or not hasattr(fn.maker, "mode"):
-                _logger.warn(
+                _logger.warning(
                     "Expected theano function not found in %s.%s", node.op, fn_attr_name
                 )
             else:
@@ -1395,7 +1453,7 @@ def _check_preallocated_output(
         dmap = getattr(node.op, "destroy_map", {})
         vmap = getattr(node.op, "view_map", {})
         for i, r in enumerate(node.inputs):
-            if any(i in v for v in chain(itervalues(dmap), itervalues(vmap))):
+            if any(i in v for v in chain(dmap.values(), vmap.values())):
                 aliased_inputs.add(r)
 
         _logger.debug("starting preallocated output checking")
@@ -1414,11 +1472,11 @@ def _check_preallocated_output(
         ):
             _logger.debug("  name = %s", name)
 
-            thunk_name = "%s with %s output" % (perform, name)
+            thunk_name = "{} with {} output".format(perform, name)
 
             if not out_map:
                 # Map is empty, there is no need to execute thunk() again
-                _logger.warn("%s: out_map is empty", name)
+                _logger.warning("%s: out_map is empty", name)
                 continue
 
             # Copy the inputs over, if they were marked as destroyed or viewed
@@ -1481,7 +1539,7 @@ def _check_preallocated_output(
             fn.maker.mode = backup_mode
 
 
-class _FunctionGraphEvent(object):
+class _FunctionGraphEvent:
     """
     A record of an event in the life of an FunctionGraph.
 
@@ -1553,7 +1611,7 @@ class _FunctionGraphEvent(object):
         return not (self == other)
 
 
-class _VariableEquivalenceTracker(object):
+class _VariableEquivalenceTracker:
     """
     A FunctionGraph Feature that keeps tabs on an FunctionGraph and
     tries to detect problems.
@@ -1624,7 +1682,7 @@ class _VariableEquivalenceTracker(object):
         else:
             for r in node.outputs:
                 assert r not in self.equiv
-                self.equiv[r] = set([r])
+                self.equiv[r] = {r}
                 self.all_variables_ever.append(r)
                 self.reasons.setdefault(r, [])
                 self.replaced_by.setdefault(r, [])
@@ -1680,13 +1738,13 @@ class _VariableEquivalenceTracker(object):
         if r in self.equiv:
             r_set = self.equiv[r]
         else:
-            r_set = self.equiv.setdefault(r, set([r]))
+            r_set = self.equiv.setdefault(r, {r})
             self.all_variables_ever.append(r)
 
         if new_r in self.equiv:
             new_r_set = self.equiv[new_r]
         else:
-            new_r_set = self.equiv.setdefault(new_r, set([new_r]))
+            new_r_set = self.equiv.setdefault(new_r, {new_r})
             self.all_variables_ever.append(new_r)
 
         assert new_r in new_r_set
@@ -1719,7 +1777,7 @@ default_make_thunk = [get_unbound_function(theano.gof.Op.make_thunk)]
 # the external requirements of the .linker attribute of a mode
 # 1) it's a class instance
 # 2) it a has a .clone() method
-class _DummyLinker(object):
+class _DummyLinker:
     # This is not a real linker anyway
     def clone(self, allow_gc=None):
         return self
@@ -1840,7 +1898,7 @@ class _Linker(gof.link.LocalLinker):
                 thunks_py.append(None)
 
             if not self.maker.mode.check_c_code and thunks_py[-1] is None:
-                _logger.warn(
+                _logger.warning(
                     "Op %s doesn't have a perform, "
                     "forcing check of the C code" % node.op
                 )
@@ -1857,7 +1915,7 @@ class _Linker(gof.link.LocalLinker):
                 elif thunks_c[-1] is None:
                     thunks_c[-1] = thunk_other
                 else:
-                    _logger.warn(
+                    _logger.warning(
                         "We won't check the perform function "
                         "of node '%s' but we will check its "
                         "make_thunk function" % node
@@ -1957,7 +2015,7 @@ class _Linker(gof.link.LocalLinker):
                 #  Precondition: the storage map is empty, transferred
                 #  completely to r_vals
                 #####
-                for r, s in iteritems(storage_map):
+                for r, s in storage_map.items():
                     if s[0] is not None:
                         print(r, s)
                     assert s[0] is None
@@ -2249,7 +2307,7 @@ class _Linker(gof.link.LocalLinker):
 
                 # Nothing should be in storage map after evaluating
                 # each the thunk (specifically the last one)
-                for r, s in iteritems(storage_map):
+                for r, s in storage_map.items():
                     assert type(s) is list
                     assert s[0] is None
 
@@ -2428,7 +2486,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
         indices = [[input] + self.expand_in(input, _inputs) for input in inputs]
 
         # make the fgraph
-        for i in xrange(mode.stability_patience):
+        for i in range(mode.stability_patience):
             fgraph, additional_outputs, equivalence_tracker = _optcheck_fgraph(
                 inputs, outputs, accept_inplace
             )
@@ -2437,7 +2495,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
             with change_flags(compute_test_value=config.compute_test_value_opt):
                 optimizer(fgraph)
 
-                theano.compile.function_module.insert_deepcopy(
+                theano.compile.function.types.insert_deepcopy(
                     fgraph, inputs, list(chain(outputs, additional_outputs))
                 )
 
@@ -2461,7 +2519,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
                         "-------------------------------------------------" "----",
                         file=infolog,
                     )
-                    for j in xrange(max(len(li), len(l0))):
+                    for j in range(max(len(li), len(l0))):
                         if j >= len(li):
                             print("trailing event in optimization 0 :", j, file=infolog)
                             print("   ", str(l0[j]), file=infolog)
@@ -2526,7 +2584,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
 
         no_borrow = [
             output
-            for output, spec in izip(fgraph.outputs, outputs + additional_outputs)
+            for output, spec in zip(fgraph.outputs, outputs + additional_outputs)
             if not spec.borrow
         ]
         if no_borrow:
@@ -2651,7 +2709,7 @@ class DebugMode(Mode):
     """
 
     # This function will be used to create a FunctionMaker in
-    # function_module.function
+    # function.types.function
     def function_maker(self, i, o, m, *args, **kwargs):
         """
         Return an instance of `_Maker` which handles much of the debugging work.
@@ -2669,7 +2727,7 @@ class DebugMode(Mode):
         check_isfinite=None,
         check_preallocated_output=None,
         require_matching_strides=None,
-        linker=_DummyLinker(),
+        linker=None,
     ):
         """
         If any of these arguments (except optimizer) is not None, it overrides
@@ -2677,6 +2735,8 @@ class DebugMode(Mode):
         allow Mode.requiring() and some other fct to work with DebugMode too.
 
         """
+        if linker is None:
+            linker = _DummyLinker()
 
         if not isinstance(linker, _DummyLinker):
             raise Exception(
@@ -2684,7 +2744,7 @@ class DebugMode(Mode):
                 linker,
             )
 
-        super(DebugMode, self).__init__(optimizer=optimizer, linker=linker)
+        super().__init__(optimizer=optimizer, linker=linker)
 
         if stability_patience is not None:
             self.stability_patience = stability_patience
@@ -2709,7 +2769,7 @@ class DebugMode(Mode):
             raise ValueError("DebugMode has to check at least one of c and py " "code")
 
     def __str__(self):
-        return "DebugMode(linker=%s, optimizer=%s)" % (
+        return "DebugMode(linker={}, optimizer={})".format(
             self.provided_linker,
             self.provided_optimizer,
         )
