@@ -6,19 +6,14 @@ help make new Ops more rapidly.
 """
 
 import copy
+import pickle
 import warnings
-
-import six.moves.cPickle as pickle
+from collections import OrderedDict
 
 import numpy as np
 
 import theano
-
-from collections import OrderedDict
-
-from six import integer_types
-
-from theano.gof import Op, Apply, ParamsType, Variable
+from theano.gof import Apply, Op, ParamsType, Variable
 
 
 def register_view_op_c_code(type, code, version=()):
@@ -75,7 +70,7 @@ class ViewOp(Op):
             return code % locals()
 
         # Else, no C code
-        return super(ViewOp, self).c_code(node, nodename, inp, out, sub)
+        return super().c_code(node, nodename, inp, out, sub)
 
     def c_code_cache_version(self):
         version = []
@@ -210,7 +205,7 @@ class DeepCopyOp(Op):
             return code % locals()
 
         # Else, no C code
-        return super(DeepCopyOp, self).c_code(node, name, inames, onames, sub)
+        return super().c_code(node, name, inames, onames, sub)
 
 
 deep_copy_op = DeepCopyOp()
@@ -265,7 +260,7 @@ class Shape(Op):
     def perform(self, node, inp, out_):
         (x,) = inp
         (out,) = out_
-        out[0] = theano._asarray(x.shape, dtype="int64")
+        out[0] = theano._asarray(np.shape(x), dtype="int64")
 
     def infer_shape(self, node, in_shapes):
         return [[len(in_shapes[0])]]
@@ -300,7 +295,7 @@ class Shape(Op):
             return code % locals()
 
         # Else, no C code
-        return super(Shape, self).c_code(node, name, inames, onames, sub)
+        return super().c_code(node, name, inames, onames, sub)
 
     def c_code_cache_version(self):
         version = []
@@ -375,9 +370,6 @@ class Shape_i(Op):
         return "%s{%i}" % (self.__class__.__name__, self.i)
 
     def make_node(self, x):
-        # x could be one of a number of types
-        # the only thing we require is that the variable have a .ndim,
-        # and that the value have a .shape
         if not isinstance(x, theano.Variable):
             raise TypeError("x must be Variable with ndim attribute", x)
         if x.ndim <= self.i:
@@ -388,9 +380,9 @@ class Shape_i(Op):
         (x,) = inp
         (out,) = out_
         if out[0] is None:
-            out[0] = theano._asarray(x.shape[self.i], dtype="int64")
+            out[0] = theano._asarray(np.shape(x)[self.i], dtype="int64")
         else:
-            out[0][...] = x.shape[self.i]
+            out[0][...] = np.shape(x)[self.i]
 
     def c_code_cache_version(self):
         version = []
@@ -427,7 +419,7 @@ class Shape_i(Op):
             return (check_input + code) % locals()
 
         # Else, no C code
-        return super(Shape_i, self).c_code(node, name, inames, onames, sub)
+        return super().c_code(node, name, inames, onames, sub)
 
     def infer_shape(self, node, input_shapes):
         return [()]
@@ -494,7 +486,7 @@ def shape_i(var, i, fgraph=None):
     # If we are not able to use the shape feature, we should not put
     # Shape_i in the graph. Otherwise, the shape feature optimization
     # won't get applied.
-    return var.shape[i]
+    return shape(var)[i]
 
 
 def shape_i_op(i):
@@ -587,7 +579,7 @@ class FromFunctionOp(Op):
             obj = load_back(mod, name)
         except (ImportError, KeyError, AttributeError):
             raise pickle.PicklingError(
-                "Can't pickle as_op(), not found as %s.%s" % (mod, name)
+                "Can't pickle as_op(), not found as {}.{}".format(mod, name)
             )
         else:
             if obj is not self:
@@ -703,7 +695,7 @@ class Rebroadcast(Op):
         items = sorted(axis)
         self.axis = OrderedDict(items)
         for axis, broad in self.axis.items():
-            if not isinstance(axis, (np.integer, integer_types)):
+            if not isinstance(axis, (np.integer, int)):
                 raise TypeError(
                     "Rebroadcast needs integer axes. " "Got {}".format(axis)
                 )
@@ -727,7 +719,7 @@ class Rebroadcast(Op):
             broadcast_pattern = ["?" for i in range(1 + max(self.axis.keys()))]
         for k, v in self.axis.items():
             broadcast_pattern[k] = str(int(v))
-        return "%s{%s}" % (self.__class__.__name__, ",".join(broadcast_pattern))
+        return "{}{{{}}}".format(self.__class__.__name__, ",".join(broadcast_pattern))
 
     def make_node(self, x):
         if self.axis.keys() and (x.ndim <= max(self.axis.keys())):
@@ -801,7 +793,7 @@ class Rebroadcast(Op):
             """
                 % locals()
             )
-        return super(Rebroadcast, self).c_code(node, nodename, inp, out, sub)
+        return super().c_code(node, nodename, inp, out, sub)
 
     def c_code_cache_version(self):
         version = []
@@ -933,7 +925,7 @@ class SpecifyShape(Op):
             _, _, support_code = self.c_code_and_version[itype]
             if support_code:
                 return support_code
-        return super(SpecifyShape, self).c_support_code_apply(node, name)
+        return super().c_support_code_apply(node, name)
 
     def c_code(self, node, name, inames, onames, sub):
         iname, shape = inames
@@ -945,7 +937,7 @@ class SpecifyShape(Op):
             code, version, _ = self.c_code_and_version[itype]
             return code % locals()
 
-        return super(SpecifyShape, self).c_code(node, node, inames, onames, sub)
+        return super().c_code(node, node, inames, onames, sub)
 
     def c_code_cache_version(self):
         version = []
