@@ -1,19 +1,19 @@
 import errno
-import os
-import sys
 import logging
-import numpy as np
+import os
 import platform
-import textwrap
 import re
 import socket
 import struct
+import sys
+import textwrap
 import warnings
 
-from six import string_types
+import numpy as np
 
 import theano
 from theano.configparser import (
+    THEANO_FLAGS_DICT,
     AddConfigVar,
     BoolParam,
     ConfigParam,
@@ -22,11 +22,10 @@ from theano.configparser import (
     IntParam,
     StrParam,
     TheanoConfigParser,
-    THEANO_FLAGS_DICT,
 )
 from theano.misc.cpucount import cpuCount
 from theano.misc.windows import call_subprocess_Popen, output_subprocess_Popen
-from theano.compat import maybe_add_to_os_environ_pathlist
+from theano.utils import maybe_add_to_os_environ_pathlist
 
 
 _logger = logging.getLogger("theano.configdefaults")
@@ -142,18 +141,16 @@ class DeviceParam(ConfigParam):
                 )
             else:
                 raise ValueError(
-                    (
-                        'Invalid value ("%s") for configuration '
-                        'variable "%s". Valid options start with '
-                        'one of "cpu", "opencl" or "cuda".' % (val, self.fullname)
-                    )
+                    'Invalid value ("%s") for configuration '
+                    'variable "%s". Valid options start with '
+                    'one of "cpu", "opencl" or "cuda".' % (val, self.fullname)
                 )
 
         over = kwargs.get("allow_override", True)
-        super(DeviceParam, self).__init__(default, filter, over)
+        super().__init__(default, filter, over)
 
     def __str__(self):
-        return "%s (%s, opencl*, cuda*) " % (self.fullname, self.default)
+        return "{} ({}, opencl*, cuda*) ".format(self.fullname, self.default)
 
 
 AddConfigVar(
@@ -211,13 +208,13 @@ class ContextsParam(ConfigParam):
             for v in val.split(";"):
                 s = v.split("->")
                 if len(s) != 2:
-                    raise ValueError("Malformed context map: %s" % (v,))
+                    raise ValueError("Malformed context map: {}".format(v))
                 if (
                     s[0] == "cpu"
                     or s[0].startswith("cuda")
                     or s[0].startswith("opencl")
                 ):
-                    raise ValueError("Cannot use %s as context name" % (s[0],))
+                    raise ValueError("Cannot use {} as context name".format(s[0]))
             return val
 
         ConfigParam.__init__(self, "", filter, False)
@@ -1409,7 +1406,7 @@ AddConfigVar(
 
 
 def is_valid_check_preallocated_output_param(param):
-    if not isinstance(param, string_types):
+    if not isinstance(param, str):
         return False
     valid = [
         "initial",
@@ -1644,13 +1641,21 @@ sure you have the right version you *will* get wrong results.
 
 
 def default_blas_ldflags():
-    global numpy
+    """Read local NumPy and MKL build settings and construct `ld` flags from them.
+
+    Returns
+    -------
+    str
+
+    """
+    import numpy.distutils  # noqa
+
     warn_record = []
     try:
-        if hasattr(np.distutils, "__config__") and np.distutils.__config__:
+        if hasattr(numpy.distutils, "__config__") and numpy.distutils.__config__:
             # If the old private interface is available use it as it
             # don't print information to the user.
-            blas_info = np.distutils.__config__.blas_opt_info
+            blas_info = numpy.distutils.__config__.blas_opt_info
         else:
             # We do this import only here, as in some setup, if we
             # just import theano and exit, with the import at global
@@ -1660,6 +1665,7 @@ def default_blas_ldflags():
             # ignored"
 
             # This happen with Python 2.7.3 |EPD 7.3-1 and numpy 1.8.1
+            # isort: off
             import numpy.distutils.system_info  # noqa
 
             # We need to catch warnings as in some cases NumPy print
@@ -1812,7 +1818,7 @@ def default_blas_ldflags():
             # we just pass the whole ldflags as the -l
             # options part.
             [
-                "-L%s%s%s" % (path_wrapper, l, path_wrapper)
+                "-L{}{}{}".format(path_wrapper, l, path_wrapper)
                 for l in blas_info.get("library_dirs", [])
             ]
             + ["-l%s" % l for l in blas_info.get("libraries", [])]
@@ -1893,7 +1899,7 @@ def try_blas_flag(flags):
     path_wrapper = '"' if os.name == "nt" else ""
     cflags.extend(
         [
-            "-L%s%s%s" % (path_wrapper, d, path_wrapper)
+            "-L{}{}{}".format(path_wrapper, d, path_wrapper)
             for d in theano.gof.cmodule.std_lib_dirs()
         ]
     )
@@ -2302,11 +2308,11 @@ def filter_compiledir(path):
     if not os.path.exists(init_file):
         try:
             open(init_file, "w").close()
-        except IOError as e:
+        except OSError as e:
             if os.path.exists(init_file):
                 pass  # has already been created
             else:
-                e.args += ("%s exist? %s" % (path, os.path.exists(path)),)
+                e.args += ("{} exist? {}".format(path, os.path.exists(path)),)
                 raise
     return path
 
@@ -2381,4 +2387,4 @@ AddConfigVar(
 
 # Check if there are remaining flags provided by the user through THEANO_FLAGS.
 for key in THEANO_FLAGS_DICT.keys():
-    warnings.warn("Theano does not recognise this flag: {0}".format(key))
+    warnings.warn("Theano does not recognise this flag: {}".format(key))
