@@ -3,25 +3,23 @@
 Author: Christof Angermueller <cangermueller@gmail.com>
 """
 import os
+from functools import reduce
 
 import numpy as np
 
 import theano
-
-from functools import reduce
-
 from theano import gof
-from theano.compile import Function
-from theano.compile import builders
+from theano.compile import Function, builders
 from theano.printing import pydot_imported, pydot_imported_msg
 
+
 try:
     from theano.printing import pd
 except ImportError:
     pass
 
 
-class PyDotFormatter(object):
+class PyDotFormatter:
     """Create `pydot` graph object from Theano function.
 
     Parameters
@@ -106,7 +104,7 @@ class PyDotFormatter(object):
 
         Parameters
         ----------
-        fct : theano.compile.function_module.Function
+        fct : theano.compile.function.types.Function
             A compiled Theano function, variable, apply or a list of variables.
         graph: pydot.Dot
             `pydot` graph to which nodes are added. Creates new one if
