@@ -2,25 +2,19 @@
 Defines Linkers that deal with C implementations.
 
 """
+import logging
 import os
 import sys
-import logging
+from copy import copy
+from io import StringIO
 
 import numpy as np
 
 import theano
-
-from copy import copy
-
-from six import string_types, reraise
-from six.moves import StringIO
-
 from theano import config
-from theano.compat import PY3
-
-from theano.gof import graph, link, utils, cmodule
-from theano.gof.compilelock import get_lock, release_lock
+from theano.gof import cmodule, graph, link, utils
 from theano.gof.callcache import CallCache
+from theano.gof.compilelock import get_lock, release_lock
 
 
 _logger = logging.getLogger("theano.gof.cc")
@@ -237,7 +231,7 @@ def struct_gen(args, struct_builders, blocks, sub):
     # declares the storage
     storage_decl = "\n".join(["PyObject* %s;" % arg for arg in args])
     # in the constructor, sets the storage to the arguments
-    storage_set = "\n".join(["this->%s = %s;" % (arg, arg) for arg in args])
+    storage_set = "\n".join(["this->{} = {};".format(arg, arg) for arg in args])
     # increments the storage's refcount in the constructor
     storage_incref = "\n".join(["Py_XINCREF(%s);" % arg for arg in args])
     # decrements the storage's refcount in the destructor
@@ -363,7 +357,7 @@ def get_c_declare(r, name, sub):
         [
             getattr(c.op, "check_input", config.check_input)
             for (c, _) in r.clients
-            if not isinstance(c, string_types)
+            if not isinstance(c, str)
         ]
     ) or (r.owner and getattr(r.owner.op, "check_input", config.check_input)):
         c_declare = r.type.c_declare(name, sub, True)
@@ -409,7 +403,7 @@ def get_c_extract(r, name, sub):
         [
             getattr(c.op, "check_input", config.check_input)
             for (c, _) in r.clients
-            if not isinstance(c, string_types)
+            if not isinstance(c, str)
         ]
     ):
         # check_broadcast is just an hack to easily remove just the
@@ -419,7 +413,7 @@ def get_c_extract(r, name, sub):
             [
                 getattr(c.op, "check_broadcast", True)
                 for (c, _) in r.clients
-                if not isinstance(c, string_types)
+                if not isinstance(c, str)
             ]
         ):
             c_extract = r.type.c_extract(name, sub, True)
@@ -853,7 +847,7 @@ class CLinker(link.Linker):
                 pass
             else:
                 # The following will be executed if the "try" block succeeds
-                assert isinstance(c_support_code_apply[-1], string_types), (
+                assert isinstance(c_support_code_apply[-1], str), (
                     str(node.op) + " didn't return a string for c_support_code_apply"
                 )
 
@@ -862,13 +856,13 @@ class CLinker(link.Linker):
             except utils.MethodNotDefined:
                 pass
             else:
-                assert isinstance(c_init_code_apply[-1], string_types), (
+                assert isinstance(c_init_code_apply[-1], str), (
                     str(node.op) + " didn't return a string for c_init_code_apply"
                 )
 
             try:
                 struct_init = op.c_init_code_struct(node, name, sub_struct)
-                assert isinstance(struct_init, string_types), (
+                assert isinstance(struct_init, str), (
                     str(node.op) + " didn't return a string for c_init_code_struct"
                 )
             except utils.MethodNotDefined:
@@ -876,7 +870,7 @@ class CLinker(link.Linker):
 
             try:
                 struct_support = op.c_support_code_struct(node, name)
-                assert isinstance(struct_support, string_types), (
+                assert isinstance(struct_support, str), (
                     str(node.op) + " didn't return a string for c_support_code_struct"
                 )
             except utils.MethodNotDefined:
@@ -884,7 +878,7 @@ class CLinker(link.Linker):
 
             try:
                 struct_cleanup = op.c_cleanup_code_struct(node, name)
-                assert isinstance(struct_cleanup, string_types), (
+                assert isinstance(struct_cleanup, str), (
                     str(node.op) + " didn't return a string for c_cleanup_code_struct"
                 )
             except utils.MethodNotDefined:
@@ -895,7 +889,7 @@ class CLinker(link.Linker):
                 behavior = op.c_code(node, name, isyms, osyms, sub)
             except utils.MethodNotDefined:
                 raise NotImplementedError("%s cannot produce C code" % op)
-            assert isinstance(behavior, string_types), (
+            assert isinstance(behavior, str), (
                 str(node.op) + " didn't return a string for c_code"
             )
             # To help understand what is following. It help read the c code.
@@ -1433,7 +1427,7 @@ class CLinker(link.Linker):
         # set of variables that have been computed by nodes we have
         # seen 'so far' in the loop below
         fgraph_computed_set = set()
-        fgraph_inputs_dict = dict((i, (-1, pos)) for pos, i in enumerate(fgraph.inputs))
+        fgraph_inputs_dict = {i: (-1, pos) for pos, i in enumerate(fgraph.inputs)}
         constant_ids = dict()
         op_pos = {}  # Apply -> topological position
 
@@ -1653,8 +1647,7 @@ class CLinker(link.Linker):
 
             # Static methods that can run and destroy the struct built by
             # instantiate.
-            if PY3:
-                static = """
+            static = """
         static int {struct_name}_executor({struct_name} *self) {{
             return self->run();
         }}
@@ -1663,21 +1656,9 @@ class CLinker(link.Linker):
             {struct_name} *self = ({struct_name} *)PyCapsule_GetContext(capsule);
             delete self;
         }}
-        """.format(
-                    struct_name=self.struct_name
-                )
-            else:
-                static = """
-        static int %(struct_name)s_executor(%(struct_name)s* self) {
-            return self->run();
-        }
-
-        static void %(struct_name)s_destructor(void* executor, void* self) {
-            delete ((%(struct_name)s*)self);
-        }
-        """ % dict(
-                    struct_name=self.struct_name
-                )
+    """.format(
+                struct_name=self.struct_name
+            )
 
             # We add all the support code, compile args, headers and libs we need.
             for support_code in self.support_code() + self.c_support_code_apply:
@@ -1774,9 +1755,8 @@ class CLinker(link.Linker):
         print("    delete struct_ptr;", file=code)
         print("    return NULL;", file=code)
         print("  }", file=code)
-        if PY3:
-            print(
-                """\
+        print(
+            """\
     PyObject* thunk = PyCapsule_New((void*)(&{struct_name}_executor), NULL, {struct_name}_destructor);
     if (thunk != NULL && PyCapsule_SetContext(thunk, struct_ptr) != 0) {{
         PyErr_Clear();
@@ -1784,21 +1764,15 @@ class CLinker(link.Linker):
         thunk = NULL;
     }}
 """.format(
-                    **locals()
-                ),
-                file=code,
-            )
-        else:
-            print(
-                "  PyObject* thunk = PyCObject_FromVoidPtrAndDesc((void*)(&%(struct_name)s_executor), struct_ptr, %(struct_name)s_destructor);"
-                % locals(),
-                file=code,
-            )
+                **locals()
+            ),
+            file=code,
+        )
         print("  return thunk; }", file=code)
         return code.getvalue()
 
 
-class _CThunk(object):
+class _CThunk:
     """
     A thunk with a C implementation.
 
@@ -1868,7 +1842,7 @@ class _CThunk(object):
                 )
                 print(self.error_storage, file=sys.stderr)
                 raise
-            reraise(exc_type, exc_value, exc_trace)
+            raise exc_value.with_traceback(exc_trace)
 
 
 class OpWiseCLinker(link.LocalLinker):
@@ -2134,7 +2108,7 @@ class DualLinker(link.Linker):
         return f, i1, o1
 
 
-class HideC(object):
+class HideC:
     def __hide(*args):
         raise utils.MethodNotDefined()
 
