@@ -3,37 +3,34 @@ Generate and compile C modules for Python.
 
 """
 import atexit
-import textwrap
-import six.moves.cPickle as pickle
+import distutils.sysconfig
 import logging
 import os
+import pickle
+import platform
 import re
 import shutil
 import stat
 import subprocess
 import sys
 import tempfile
+import textwrap
 import time
-import platform
-import distutils.sysconfig
 import warnings
+from io import BytesIO, StringIO
 
 import numpy.distutils
 
 import theano
-
-from six import b, BytesIO, StringIO, string_types
-
-
 from theano import config
-from theano.compat import PY3, decode, decode_iter
-from theano.gof.utils import flatten
-from theano.gof.utils import hash_from_code
-from theano.misc.windows import subprocess_Popen, output_subprocess_Popen
+from theano.configdefaults import gcc_version_str, local_bitwidth
 
 # we will abuse the lockfile mechanism when reading and writing the registry
 from theano.gof import compilelock
-from theano.configdefaults import gcc_version_str, local_bitwidth
+from theano.gof.utils import flatten, hash_from_code
+from theano.misc.windows import output_subprocess_Popen, subprocess_Popen
+from theano.utils import decode, decode_iter
+
 
 importlib = None
 try:
@@ -56,8 +53,6 @@ class MissingGXX(Exception):
 
     """
 
-    pass
-
 
 def debug_counter(name, every=1):
     """
@@ -73,10 +68,10 @@ def debug_counter(name, every=1):
     setattr(debug_counter, name, getattr(debug_counter, name, 0) + 1)
     n = getattr(debug_counter, name)
     if n % every == 0:
-        print("debug_counter [%s]: %s" % (name, n), file=sys.stderr)
+        print("debug_counter [{}]: {}".format(name, n), file=sys.stderr)
 
 
-class ExtFunction(object):
+class ExtFunction:
     """
     A C function to put into a DynamicModule.
 
@@ -121,10 +116,12 @@ class ExtFunction(object):
         It goes into the DynamicModule's method table.
 
         """
-        return '\t{"%s", %s, %s, "%s"}' % (self.name, self.name, self.method, self.doc)
+        return '\t{{"{}", {}, {}, "{}"}}'.format(
+            self.name, self.name, self.method, self.doc
+        )
 
 
-class DynamicModule(object):
+class DynamicModule:
     def __init__(self, name=None):
         assert name is None, (
             "The 'name' parameter of DynamicModule"
@@ -152,38 +149,28 @@ class DynamicModule(object):
         print("};", file=stream)
 
     def print_init(self, stream):
-        if PY3:
-            print(
-                """\
+        print(
+            """\
 static struct PyModuleDef moduledef = {{
-      PyModuleDef_HEAD_INIT,
-      "{name}",
-      NULL,
-      -1,
-      MyMethods,
+  PyModuleDef_HEAD_INIT,
+  "{name}",
+  NULL,
+  -1,
+  MyMethods,
 }};
 """.format(
-                    name=self.hash_placeholder
-                ),
-                file=stream,
-            )
-            print(
-                ("PyMODINIT_FUNC PyInit_%s(void) {" % self.hash_placeholder),
-                file=stream,
-            )
-            for block in self.init_blocks:
-                print("  ", block, file=stream)
-            print("    PyObject *m = PyModule_Create(&moduledef);", file=stream)
-            print("    return m;", file=stream)
-        else:
-            print(("PyMODINIT_FUNC init%s(void){" % self.hash_placeholder), file=stream)
-            for block in self.init_blocks:
-                print("  ", block, file=stream)
-            print(
-                "  ",
-                ('(void) Py_InitModule("%s", MyMethods);' % self.hash_placeholder),
-                file=stream,
-            )
+                name=self.hash_placeholder
+            ),
+            file=stream,
+        )
+        print(
+            ("PyMODINIT_FUNC PyInit_%s(void) {" % self.hash_placeholder),
+            file=stream,
+        )
+        for block in self.init_blocks:
+            print("  ", block, file=stream)
+        print("    PyObject *m = PyModule_Create(&moduledef);", file=stream)
+        print("    return m;", file=stream)
         print("}", file=stream)
 
     def add_include(self, str):
@@ -439,7 +426,7 @@ def get_module_hash(src_code, key):
             # This should be the C++ compilation command line parameters or the
             # libraries to link against.
             to_hash += list(key_element)
-        elif isinstance(key_element, string_types):
+        elif isinstance(key_element, str):
             if key_element.startswith("md5:") or key_element.startswith("hash:"):
                 # This is actually a sha256 hash of the config options.
                 # Currently, we still keep md5 to don't break old Theano.
@@ -484,7 +471,7 @@ def get_safe_part(key):
     # rest of the cache mechanism will just skip that key.
     hash = None
     for key_element in c_link_key[1:]:
-        if isinstance(key_element, string_types):
+        if isinstance(key_element, str):
             if key_element.startswith("md5:"):
                 hash = key_element[4:]
                 break
@@ -495,7 +482,7 @@ def get_safe_part(key):
     return key[0] + (hash,)
 
 
-class KeyData(object):
+class KeyData:
     """
     Used to store the key information in the cache.
 
@@ -597,7 +584,7 @@ class KeyData(object):
                     pass
 
 
-class ModuleCache(object):
+class ModuleCache:
     """
     Interface to the cache of dynamically compiled modules on disk.
 
@@ -1014,7 +1001,7 @@ class ModuleCache(object):
                 # Test to see that the file is [present and] readable.
                 open(entry).close()
                 gone = False
-            except IOError:
+            except OSError:
                 gone = True
 
             if gone:
@@ -1143,7 +1130,7 @@ class ModuleCache(object):
         key_pkl = os.path.join(location, "key.pkl")
         assert not os.path.exists(key_pkl)
         key_data = KeyData(
-            keys=set([key]), module_hash=module_hash, key_pkl=key_pkl, entry=name
+            keys={key}, module_hash=module_hash, key_pkl=key_pkl, entry=name
         )
 
         key_broken = False
@@ -1521,7 +1508,7 @@ class ModuleCache(object):
                     fname = os.path.join(self.dirname, filename, "key.pkl")
                     open(fname).close()
                     has_key = True
-                except IOError:
+                except OSError:
                     has_key = False
                 if not has_key:
                     # Use the compiled file by default
@@ -1727,12 +1714,10 @@ def std_lib_dirs_and_libs():
             for f, lib in [("libpython27.a", "libpython 1.2")]:
                 if not os.path.exists(os.path.join(libdir, f)):
                     print(
-                        (
-                            "Your Python version is from Canopy. "
-                            + "You need to install the package '"
-                            + lib
-                            + "' from Canopy package manager."
-                        )
+                        "Your Python version is from Canopy. "
+                        + "You need to install the package '"
+                        + lib
+                        + "' from Canopy package manager."
                     )
             libdirs = [
                 # Used in older Canopy
@@ -1750,12 +1735,10 @@ def std_lib_dirs_and_libs():
                     ]
                 ):
                     print(
-                        (
-                            "Your Python version is from Canopy. "
-                            + "You need to install the package '"
-                            + lib
-                            + "' from Canopy package manager."
-                        )
+                        "Your Python version is from Canopy. "
+                        + "You need to install the package '"
+                        + lib
+                        + "' from Canopy package manager."
                     )
             python_lib_dirs.insert(0, libdir)
         std_lib_dirs_and_libs.data = [libname], python_lib_dirs
@@ -1836,15 +1819,15 @@ def gcc_llvm():
             # Normally this should not happen as we should not try to
             # compile when g++ is not available. If this happen, it
             # will crash later so supposing it is not llvm is "safe".
-            output = b("")
-        gcc_llvm.is_llvm = b("llvm") in output
+            output = b""
+        gcc_llvm.is_llvm = b"llvm" in output
     return gcc_llvm.is_llvm
 
 
 gcc_llvm.is_llvm = None
 
 
-class Compiler(object):
+class Compiler:
     """
     Meta compiler that offer some generic function.
 
@@ -1895,10 +1878,9 @@ class Compiler(object):
                 path = '"' + path + '"'
                 exe_path = '"' + exe_path + '"'
             try:
-                # Python3 compatibility: try to cast Py3 strings as Py2 strings
                 try:
-                    src_code = b(src_code)
-                except Exception:
+                    src_code = src_code.encode()
+                except AttributeError:  # src_code was already bytes
                     pass
                 os.write(fd, src_code)
                 os.close(fd)
@@ -1962,7 +1944,7 @@ class Compiler(object):
         if not compiler:
             return False
 
-        code = b(
+        code = (
             """
         %(preambule)s
         int main(int argc, char** argv)
@@ -1972,7 +1954,7 @@ class Compiler(object):
         }
         """
             % locals()
-        )
+        ).encode()
         return cls._try_compile_tmp(
             code,
             tmp_prefix="try_flags_",
@@ -2055,7 +2037,7 @@ class GCC_compiler(Compiler):
             and "clang-omp++" not in theano.config.cxx
             and "icpc" not in theano.config.cxx
         ):
-            _logger.warn(
+            _logger.warning(
                 "OPTIMIZATION WARNING: your Theano flag `cxx` seems not to be"
                 " the g++ compiler. So we disable the compiler optimization"
                 " specific to g++ that tell to compile for a specific CPU."
@@ -2080,7 +2062,7 @@ class GCC_compiler(Compiler):
                 # as stdin (which is the default) results in the process
                 # waiting forever without returning. For that reason,
                 # we use a pipe, and use the empty string as input.
-                (stdout, stderr) = p.communicate(input=b(""))
+                (stdout, stderr) = p.communicate(input=b"")
                 if p.returncode != 0:
                     return None
 
@@ -2124,7 +2106,7 @@ class GCC_compiler(Compiler):
                     )
                 else:
                     reported_lines = native_lines
-                _logger.warn(
+                _logger.warning(
                     "OPTIMIZATION WARNING: Theano was not able to find the"
                     " g++ parameters that tune the compilation to your "
                     " specific CPU. This can slow down the execution of Theano"
@@ -2137,7 +2119,7 @@ class GCC_compiler(Compiler):
                 default_lines = get_lines("%s -E -v -" % theano.config.cxx)
                 _logger.info("g++ default lines: %s", default_lines)
                 if len(default_lines) < 1:
-                    _logger.warn(
+                    _logger.warning(
                         "OPTIMIZATION WARNING: Theano was not able to find the"
                         " default g++ parameters. This is needed to tune"
                         " the compilation to your specific"
@@ -2358,7 +2340,7 @@ class GCC_compiler(Compiler):
                             line.startswith("#define hypot _hypot") for line in config_h
                         ):
                             cxxflags.append("-D_hypot=hypot")
-                except IOError:
+                except OSError:
                     pass
 
         return cxxflags
@@ -2475,9 +2457,9 @@ class GCC_compiler(Compiler):
             if dist_suffix is not None and dist_suffix != "":
                 suffix = dist_suffix
 
-            filepath = "%s%s" % (module_name, suffix)
+            filepath = "{}{}".format(module_name, suffix)
         else:
-            filepath = "%s.%s" % (module_name, get_lib_extension())
+            filepath = "{}.{}".format(module_name, get_lib_extension())
 
         lib_filename = os.path.join(location, filepath)
 
@@ -2491,10 +2473,13 @@ class GCC_compiler(Compiler):
         # to support path that includes spaces, we need to wrap it with double quotes on Windows
         path_wrapper = '"' if os.name == "nt" else ""
         cmd.extend(
-            ["-I%s%s%s" % (path_wrapper, idir, path_wrapper) for idir in include_dirs]
+            [
+                "-I{}{}{}".format(path_wrapper, idir, path_wrapper)
+                for idir in include_dirs
+            ]
         )
         cmd.extend(
-            ["-L%s%s%s" % (path_wrapper, ldir, path_wrapper) for ldir in lib_dirs]
+            ["-L{}{}{}".format(path_wrapper, ldir, path_wrapper) for ldir in lib_dirs]
         )
         if hide_symbols and sys.platform != "win32":
             # This has been available since gcc 4.0 so we suppose it
@@ -2504,8 +2489,8 @@ class GCC_compiler(Compiler):
             # improved loading times on most platforms (win32 is
             # different, as usual).
             cmd.append("-fvisibility=hidden")
-        cmd.extend(["-o", "%s%s%s" % (path_wrapper, lib_filename, path_wrapper)])
-        cmd.append("%s%s%s" % (path_wrapper, cppfilename, path_wrapper))
+        cmd.extend(["-o", "{}{}{}".format(path_wrapper, lib_filename, path_wrapper)])
+        cmd.append("{}{}{}".format(path_wrapper, cppfilename, path_wrapper))
         cmd.extend(["-l%s" % l for l in libs])
         # print >> sys.stderr, 'COMPILING W CMD', cmd
         _logger.debug("Running cmd: %s", " ".join(cmd))
