@@ -5,18 +5,16 @@ types that it can raise.
 
 """
 import time
+from collections import OrderedDict
+from io import StringIO
 
 import theano
-
-from collections import OrderedDict
-
-from six.moves import StringIO
-
 from theano import config
-from theano.gof import graph, utils, toolbox
-from theano.gof.utils import get_variable_trace_string
+from theano.gof import graph, toolbox, utils
+from theano.gof.utils import TestValueError, get_variable_trace_string
 from theano.misc.ordered_set import OrderedSet
 
+
 NullType = None
 
 
@@ -27,8 +25,6 @@ class InconsistencyError(Exception):
 
     """
 
-    pass
-
 
 class MissingInputError(Exception):
     """
@@ -511,7 +507,7 @@ class FunctionGraph(utils.object2):
             try:
                 tval = theano.gof.op.get_test_value(r)
                 new_tval = theano.gof.op.get_test_value(new_r)
-            except AttributeError:
+            except TestValueError:
                 pass
             else:
                 tval_shape = getattr(tval, "shape", None)
