@@ -3,32 +3,36 @@ Node classes (`Apply`, `Variable`) and expression graph algorithms.
 """
 import contextlib
 import warnings
-
-import theano
-
 from collections import deque
 from copy import copy
 from itertools import count
 
-from six import string_types, integer_types
-
+import theano
 from theano import config
-from theano.gof import utils
+from theano.gof.utils import (
+    MethodNotDefined,
+    Scratchpad,
+    TestValueError,
+    ValidatingScratchpad,
+    add_tag_trace,
+    get_variable_trace_string,
+    object2,
+)
 from theano.misc.ordered_set import OrderedSet
 
+
 __docformat__ = "restructuredtext en"
 
 NoParams = object()
 
 
-class Node(utils.object2):
-    """
-    A Node in a theano graph.
+class Node(object2):
+    """A `Node` in a Theano graph.
 
-    Graphs contain two kinds of Nodes -- Variable and Apply.
+    Currently, graphs contain two kinds of `Nodes`: `Variable`s and `Apply`s.
     Edges in the graph are not explicitly represented.
-    Instead each Node keeps track of its parents via
-    Variable.owner / Apply.inputs and its children
+    Instead each `Node` keeps track of its parents via
+    `Variable.owner` / `Apply.inputs` and its children
     via Variable.clients / Apply.outputs.
 
     """
@@ -44,55 +48,53 @@ class Node(utils.object2):
 
 
 class Apply(Node):
-    """
-    An :term:`Apply` instance is a node in an expression graph which represents
-    the application of an `Op` to some input `Variable` nodes, producing some
-    output `Variable` nodes.
+    """A `Node` representing the application of an operation to inputs.
 
-    This class is typically instantiated by an Op's make_node() function, which
-    is typically called by that Op's __call__() function.
-
-    An Apply instance serves as a simple structure with three important
+    An `Apply` instance serves as a simple structure with three important
     attributes:
 
     - :literal:`inputs` :  a list of `Variable` nodes that represent the
       arguments of the expression,
 
     - :literal:`outputs` : a list of `Variable` nodes that represent the
-      variable of the expression, and
+      computed outputs of the expression, and
 
     - :literal:`op` : an `Op` instance that determines the nature of the
       expression being applied.
 
-    The driver `compile.function` uses Apply's inputs attribute together with
-    Variable's owner attribute to search the expression graph and determine
+    Basically, an `Apply` instance is an object that represents the
+    Python statement `outputs = op(*inputs)`.
+
+    This class is typically instantiated by a `PureOp.make_node` method, which
+    is called by `PureOp.__call__`.
+
+    The function `theano.compile.function.function` uses `Apply.inputs`
+    together with `Variable.owner` to search the expression graph and determine
     which inputs are necessary to compute the function's outputs.
 
-    A `Linker` uses the Apply instance's `op` field to compute the variables.
-
-    Comparing with the Python language, an `Apply` instance is theano's version
-    of a function call (or expression instance) whereas `Op` is theano's version
-    of a function definition.
+    A `Linker` uses the `Apply` instance's `op` field to compute numeric values
+    for the output variables.
 
     Parameters
     ----------
-    op : `Op` instance
+    op : A PureOp instance
     inputs : list of Variable instances
     outputs : list of Variable instances
 
     Notes
     -----
-    The owner field of each output in the outputs list will be set to self.
+    The `Variable.owner` field of each `Apply.outputs` element is set to `self`
+    in `Apply.make_node`.
 
-    If an output element has an owner that is neither None nor self, then a
-    ValueError exception will be raised.
+    If an output element has an owner that is neither `None` nor `self`, then a
+    `ValueError` exception will be raised.
 
     """
 
     def __init__(self, op, inputs, outputs):
         self.op = op
         self.inputs = []
-        self.tag = utils.scratchpad()
+        self.tag = Scratchpad()
 
         if not isinstance(inputs, (list, tuple)):
             raise TypeError("The inputs of an Apply must be a list or tuple")
@@ -134,7 +136,7 @@ class Apply(Node):
         """
         try:
             return self.op.get_params(self)
-        except theano.gof.utils.MethodNotDefined:
+        except MethodNotDefined:
             return NoParams
 
     def __getstate__(self):
@@ -167,13 +169,13 @@ class Apply(Node):
             if len(self.outputs) == 1:
                 return self.outputs[0]
             else:
-                raise AttributeError(
+                raise ValueError(
                     "%s.default_output should be an output index." % self.op
                 )
-        elif not isinstance(do, integer_types):
-            raise AttributeError("%s.default_output should be an int or long" % self.op)
+        elif not isinstance(do, int):
+            raise ValueError("%s.default_output should be an int or long" % self.op)
         elif do < 0 or do >= len(self.outputs):
-            raise AttributeError("%s.default_output is out of range." % self.op)
+            raise ValueError("%s.default_output is out of range." % self.op)
         return self.outputs[do]
 
     out = property(default_output, doc="alias for self.default_output()")
@@ -348,10 +350,10 @@ class Variable(Node):
     .. code-block:: python
 
         import theano
-        from theano import tensor
+        import theano.tensor as tt
 
-        a = tensor.constant(1.5)        # declare a symbolic constant
-        b = tensor.fscalar()            # declare a symbolic floating-point scalar
+        a = tt.constant(1.5)            # declare a symbolic constant
+        b = tt.fscalar()                # declare a symbolic floating-point scalar
 
         c = a + b                       # create a simple expression
 
@@ -363,7 +365,7 @@ class Variable(Node):
 
         theano.function([a,b], [c])     # compilation error because a is constant, it can't be an input
 
-        d = tensor.value(1.5)           # create a value similar to the constant 'a'
+        d = tt.value(1.5)               # create a value similar to the constant 'a'
         e = d + b
         theano.function([d,b], [e])     # this works.  d's default value of 1.5 is ignored.
 
@@ -371,33 +373,50 @@ class Variable(Node):
     `Variable`. The `Variable` referred to by `a` is also an instance of
     `Constant`.
 
-    `compile.function` uses each `Apply` instance's `inputs` attribute together
-    with each Variable's `owner` field to determine which inputs are necessary
-    to compute the function's outputs.
-
     """
 
     # __slots__ = ['type', 'owner', 'index', 'name']
     __count__ = count(0)
 
     def __init__(self, type, owner=None, index=None, name=None):
-        super(Variable, self).__init__()
+        super().__init__()
+
+        self.tag = ValidatingScratchpad("test_value", type.filter)
 
-        self.tag = utils.scratchpad()
         self.type = type
+
         if owner is not None and not isinstance(owner, Apply):
             raise TypeError("owner must be an Apply instance", owner)
         self.owner = owner
-        if index is not None and not isinstance(index, integer_types):
+
+        if index is not None and not isinstance(index, int):
             raise TypeError("index must be an int", index)
         self.index = index
-        if name is not None and not isinstance(name, string_types):
+
+        if name is not None and not isinstance(name, str):
             raise TypeError("name must be a string", name)
         self.name = name
+
         self.auto_name = "auto_" + str(next(self.__count__))
 
         Variable.notify_construction_observers(self)
 
+    def get_test_value(self):
+        """Get the test value.
+
+        Raises
+        ------
+        TestValueError
+
+        """
+        if not hasattr(self.tag, "test_value"):
+            detailed_err_msg = get_variable_trace_string(self)
+            raise TestValueError(
+                "{} has no test value {}".format(self, detailed_err_msg)
+            )
+
+        return self.tag.test_value
+
     def __str__(self):
         """Return a str representation of the Variable."""
         if self.name is not None:
@@ -418,7 +437,7 @@ class Variable(Node):
         overridden by classes with non printable test_value to provide a
         suitable representation of the test_value.
         """
-        return repr(theano.gof.op.get_test_value(self))
+        return repr(self.get_test_value())
 
     def __repr__(self, firstPass=True):
         """Return a repr of the Variable.
@@ -431,7 +450,7 @@ class Variable(Node):
         if config.print_test_value and firstPass:
             try:
                 to_print.append(self.__repr_test_value__())
-            except AttributeError:
+            except TestValueError:
                 pass
         return "\n".join(to_print)
 
@@ -495,9 +514,9 @@ class Variable(Node):
         --------
 
         >>> import numpy as np
-        >>> import theano.tensor as T
-        >>> x = T.dscalar('x')
-        >>> y = T.dscalar('y')
+        >>> import theano.tensor as tt
+        >>> x = tt.dscalar('x')
+        >>> y = tt.dscalar('y')
         >>> z = x + y
         >>> np.allclose(z.eval({x : 16.3, y : 12.1}), 28.4)
         True
@@ -566,27 +585,27 @@ class Variable(Node):
 
 
 class Constant(Variable):
-    """
-    A :term:`Constant` is a `Variable` with a `value` field that cannot be
-    changed at runtime.
+    """A `Variable` with a fixed `value` field.
 
-    Constant nodes make eligible numerous optimizations: constant inlining in
-    C code, constant folding, etc.
+    Constant nodes make numerous optimizations possible (e.g. constant inlining
+    in C code, constant folding, etc.)
 
     Notes
     -----
     The data field is filtered by what is provided in the constructor for the
-    Constant's type field.
-
-    WRITEME
+    `Constant`'s type field.
 
     """
 
     # __slots__ = ['data']
+
     def __init__(self, type, data, name=None):
-        Variable.__init__(self, type, None, None, name)
+        super().__init__(type, None, None, name)
         self.data = type.filter(data)
-        utils.add_tag_trace(self)
+        add_tag_trace(self)
+
+    def get_test_value(self):
+        return self.data
 
     def equals(self, other):
         # this does what __eq__ should do, but Variable and Apply should always be hashable by id
@@ -1131,7 +1150,7 @@ default_leaf_formatter = str
 
 
 def default_node_formatter(op, argstrings):
-    return "%s(%s)" % (op.op, ", ".join(argstrings))
+    return "{}({})".format(op.op, ", ".join(argstrings))
 
 
 def io_connection_pattern(inputs, outputs):
@@ -1306,7 +1325,7 @@ def view_roots(r):
     if owner is not None:
         try:
             view_map = owner.op.view_map
-            view_map = dict((owner.outputs[o], i) for o, i in view_map.items())
+            view_map = {owner.outputs[o]: i for o, i in view_map.items()}
         except AttributeError:
             return [r]
         if r in view_map:
