@@ -5,25 +5,30 @@ The `Op` class is the base interface for all operations
 compatible with `gof`'s :doc:`graph` routines.
 
 """
+import copy
+import inspect
+import logging
 import os
 import re
 import sys
-import inspect
-import logging
 import warnings
 
 import numpy as np
 
 import theano
 import theano.gof.cc
-
-from six import PY3
-
 from theano import config
 from theano.gof import graph
-from theano.gof import utils
 from theano.gof.cmodule import GCC_compiler
 from theano.gof.fg import FunctionGraph
+from theano.gof.utils import (
+    MethodNotDefined,
+    TestValueError,
+    add_tag_trace,
+    get_variable_trace_string,
+    object2,
+)
+
 
 __authors__ = "theano-dev"
 __copyright__ = "(c) 2010, Universite de Montreal"
@@ -35,19 +40,90 @@ __docformat__ = "restructuredtext en"
 _logger = logging.getLogger("theano.gof.op.Op")
 
 
-# Open file in "universal newline mode".
-# In Python 2, this is done by calling open(..., 'U'), but this is
-# deprected in Python 3 (where we would need to pass "newline=None",
-# which is the default).
-if PY3:
-    _open_u = open
-else:
+def compute_test_value(node):
+    """Computes the test value of a node.
 
-    def _open_u(file):
-        return open(file, "U")
+    Parameters
+    ----------
+    node : Apply
+        The `Apply` node for which the test value is computed.
+
+    Returns
+    -------
+    None
+        The `tag.test_value`s are updated in each `Variable` in `node.outputs`.
+
+    """
+    # Gather the test values for each input of the node
+    storage_map = {}
+    compute_map = {}
+    for i, ins in enumerate(node.inputs):
+        try:
+            storage_map[ins] = [ins.get_test_value()]
+            compute_map[ins] = [True]
+        except TestValueError:
+            # no test-value was specified, act accordingly
+            if config.compute_test_value == "warn":
+                warnings.warn(
+                    "Warning, Cannot compute test value: input %i (%s) of Op %s missing default value"
+                    % (i, ins, node),
+                    stacklevel=2,
+                )
+                return
+            elif config.compute_test_value == "raise":
+                detailed_err_msg = get_variable_trace_string(ins)
+
+                raise ValueError(
+                    "Cannot compute test value: input %i (%s) of Op %s missing default value. %s"
+                    % (i, ins, node, detailed_err_msg)
+                )
+            elif config.compute_test_value == "ignore":
+                return
+            elif config.compute_test_value == "pdb":
+                import pdb
+
+                pdb.post_mortem(sys.exc_info()[2])
+            else:
+                raise ValueError(
+                    "%s is invalid for option config.compute_test_value"
+                    % config.compute_test_value
+                )
+
+    # All inputs have test-values; perform the `Op`'s computation
+
+    # The original values should not be destroyed, so we copy the values of the
+    # inputs in `destroy_map`
+    destroyed_inputs_idx = set()
+    if getattr(node.op, "destroy_map", None):
+        for i_pos_list in node.op.destroy_map.values():
+            destroyed_inputs_idx.update(i_pos_list)
+    for inp_idx in destroyed_inputs_idx:
+        inp = node.inputs[inp_idx]
+        storage_map[inp] = [copy.copy(storage_map[inp][0])]
+
+    # Prepare `storage_map` and `compute_map` for the outputs
+    for o in node.outputs:
+        storage_map[o] = [None]
+        compute_map[o] = [False]
+
+    # Create a thunk that performs the computation
+    thunk = node.op.make_thunk(node, storage_map, compute_map, no_recycling=[])
+    thunk.inputs = [storage_map[v] for v in node.inputs]
+    thunk.outputs = [storage_map[v] for v in node.outputs]
+
+    required = thunk()
+    assert not required  # We provided all inputs
+
+    for output in node.outputs:
+        # Check that the output has been computed
+        assert compute_map[output][0], (output, storage_map[output][0])
+
+        # Add 'test_value' to output tag, so that downstream `Op`s can use
+        # these numerical values as test values
+        output.tag.test_value = storage_map[output][0]
 
 
-class CLinkerObject(object):
+class CLinkerObject:
     """
     Standard elements of an Op or Type used with the CLinker.
 
@@ -74,7 +150,7 @@ class CLinkerObject(object):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined("c_headers", type(self), self.__class__.__name__)
+        raise MethodNotDefined("c_headers", type(self), self.__class__.__name__)
 
     def c_header_dirs(self):
         """
@@ -97,9 +173,7 @@ class CLinkerObject(object):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined(
-            "c_header_dirs", type(self), self.__class__.__name__
-        )
+        raise MethodNotDefined("c_header_dirs", type(self), self.__class__.__name__)
 
     def c_libraries(self):
         """
@@ -122,7 +196,7 @@ class CLinkerObject(object):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined("c_libraries", type(self), self.__class__.__name__)
+        raise MethodNotDefined("c_libraries", type(self), self.__class__.__name__)
 
     def c_lib_dirs(self):
         """
@@ -145,7 +219,7 @@ class CLinkerObject(object):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined("c_lib_dirs", type(self), self.__class__.__name__)
+        raise MethodNotDefined("c_lib_dirs", type(self), self.__class__.__name__)
 
     def c_support_code(self):
         """
@@ -161,9 +235,7 @@ class CLinkerObject(object):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined(
-            "c_support_code", type(self), self.__class__.__name__
-        )
+        raise MethodNotDefined("c_support_code", type(self), self.__class__.__name__)
 
     def c_code_cache_version(self):
         """
@@ -201,9 +273,7 @@ class CLinkerObject(object):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined(
-            "c_compile_args", type(self), self.__class__.__name__
-        )
+        raise MethodNotDefined("c_compile_args", type(self), self.__class__.__name__)
 
     def c_no_compile_args(self):
         """
@@ -224,9 +294,7 @@ class CLinkerObject(object):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined(
-            "c_no_compile_args", type(self), self.__class__.__name__
-        )
+        raise MethodNotDefined("c_no_compile_args", type(self), self.__class__.__name__)
 
     def c_init_code(self):
         """
@@ -239,7 +307,7 @@ class CLinkerObject(object):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined("c_init_code", type(self), self.__class__.__name__)
+        raise MethodNotDefined("c_init_code", type(self), self.__class__.__name__)
 
 
 class CLinkerOp(CLinkerObject):
@@ -293,7 +361,7 @@ class CLinkerOp(CLinkerObject):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined("%s.c_code" % self.__class__.__name__)
+        raise MethodNotDefined("%s.c_code" % self.__class__.__name__)
 
     def c_code_cache_version_apply(self, node):
         """
@@ -354,7 +422,7 @@ class CLinkerOp(CLinkerObject):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined("%s.c_code_cleanup" % self.__class__.__name__)
+        raise MethodNotDefined("%s.c_code_cleanup" % self.__class__.__name__)
 
     def c_support_code_apply(self, node, name):
         """
@@ -382,7 +450,7 @@ class CLinkerOp(CLinkerObject):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined(
+        raise MethodNotDefined(
             "c_support_code_apply", type(self), self.__class__.__name__
         )
 
@@ -411,9 +479,7 @@ class CLinkerOp(CLinkerObject):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined(
-            "c_init_code_apply", type(self), self.__class__.__name__
-        )
+        raise MethodNotDefined("c_init_code_apply", type(self), self.__class__.__name__)
 
     def c_init_code_struct(self, node, name, sub):
         """
@@ -436,7 +502,7 @@ class CLinkerOp(CLinkerObject):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined(
+        raise MethodNotDefined(
             "c_init_code_struct", type(self), self.__class__.__name__
         )
 
@@ -459,7 +525,7 @@ class CLinkerOp(CLinkerObject):
             Subclass does not implement this method.
 
         """
-        raise utils.MethodNotDefined(
+        raise MethodNotDefined(
             "c_support_code_struct", type(self), self.__class__.__name__
         )
 
@@ -480,107 +546,59 @@ class CLinkerOp(CLinkerObject):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined(
+        raise MethodNotDefined(
             "c_cleanup_code_struct", type(self), self.__class__.__name__
         )
 
 
-class PureOp(object):
-    """
-    An :term:`Op` is a type of operation.
+class PureOp:
+    """A class that models and constructs operations in a graph.
 
-    `Op` is an abstract class that documents the interface for theano's data
-    transformations. It has many subclasses, such as
-    `sparse dot <http://pylearn.org/epydoc/theano.sparse.Dot-class.html>`__,
-    and `Shape <http://pylearn.org/epydoc/theano.tensor.Shape-class.html>`__.
+    A `PureOp` instance has several responsibilities:
 
-    These subclasses are meant to be instantiated.
-    An instance has several responsabilities:
+    - construct `Apply` nodes via `PureOp.make_node` method,
 
-    - making `Apply` instances, which mean "apply this type of operation to some
-      particular inputs" (via `make_node`),
+    - perform the numeric calculation of the modeled operation via
+    the `PureOp.perform` method,
 
-    - performing the calculation of outputs from given inputs
-      (via the `perform`),
+    - and (optionally) build the gradient-calculating sub-graphs via the
+    `PureOp.grad` method.
 
-    - [optionally] building gradient-calculating graphs (via `grad`).
+    To see how `PureOp`, `Type`, `Variable`, and `Apply` fit together see the
+    page on :doc:`graph`.
 
-    To see how `Op`, `Type`, `Variable`, and `Apply` fit together see the page
-    on :doc:`graph`.
-
-    For more specifications on how these methods should behave: see the
-    `Op Contract` in the sphinx docs (advanced tutorial on Op-making).
+    For more details regarding how these methods should behave: see the `Op
+    Contract` in the sphinx docs (advanced tutorial on `Op`-making).
 
     """
 
     default_output = None
     """
-    Configuration variable for `__call__`.
+    An `int` that specifies which output `PureOp.__call__` should return.  If
+    `None`, then all outputs are returned.
 
-    A subclass should not change this class variable, but instead over-ride it with a subclass
-    variable or an instance variable.
+    A subclass should not change this class variable, but instead override it
+    with a subclass variable or an instance variable.
 
     """
 
-    #############
-    # make_node #
-    #############
-
     def make_node(self, *inputs):
-        """
-        Required: return an Apply instance representing the
-        application of this Op to the provided inputs.
+        """Construct an `Apply` node that represent the application of this operation to the given inputs.
+
+        This must be implemented by sub-classes.
+
+        Returns
+        -------
+        node: Apply
+            The constructed `Apply` node.
 
         """
-        raise utils.MethodNotDefined("make_node", type(self), self.__class__.__name__)
-
-    @classmethod
-    def _get_test_value(cls, v):
-        """
-        Extract test value from variable v.
-        Raises AttributeError if there is none.
-
-        For a Constant, the test value is v.value.
-        For a Shared variable, it is the internal value.
-        For another Variable, it is the content of v.tag.test_value.
-
-        """
-        # avoid circular import
-        from theano.compile.sharedvalue import SharedVariable
-
-        if isinstance(v, graph.Constant):
-            return v.value
-        elif isinstance(v, SharedVariable):
-            return v.get_value(borrow=True, return_internal_type=True)
-        elif isinstance(v, graph.Variable) and hasattr(v.tag, "test_value"):
-            # ensure that the test value is correct
-            try:
-                ret = v.type.filter(v.tag.test_value)
-            except Exception as e:
-                # Better error message.
-                detailed_err_msg = (
-                    "For compute_test_value, one input test value does not"
-                    " have the requested type.\n"
-                )
-                detailed_err_msg += utils.get_variable_trace_string(v)
-
-                detailed_err_msg += (
-                    "\nThe error when converting the test value to that"
-                    " variable type:"
-                )
-                # We need to only have 1 args and it should be of type
-                # string.  Otherwise, it print the tuple and so the
-                # new line do not get printed.
-                args = (detailed_err_msg,) + tuple(str(arg) for arg in e.args)
-                e.args = ("\n".join(args),)
-                raise
-            return ret
-        detailed_err_msg = utils.get_variable_trace_string(v)
-        raise AttributeError("%s has no test value %s" % (v, detailed_err_msg))
+        raise MethodNotDefined("make_node", type(self), self.__class__.__name__)
 
     def __call__(self, *inputs, **kwargs):
-        """
-        Optional: return some or all output[s] of `make_node`.
+        """Construct an `Apply` node using `self.make_node` and return its outputs.
+
+        This method is just a wrapper around `PureOp.make_node`.
 
         It is called by code such as:
 
@@ -588,103 +606,43 @@ class PureOp(object):
 
            x = tensor.matrix()
 
-           # tensor.exp is an Op instance, calls
-           # Op.__call__(self=<instance of exp>, inputs=(x,))
            y = tensor.exp(x)
 
-        This class implements a convenience function (for graph-building) which
-        uses `default_output`, but subclasses are free to override this function
-        and ignore `default_output`.
+        `tensor.exp` is an Op instance, so `tensor.exp(x)` calls
+        `tensor.exp.__call__` (i.e. this method) and returns its single output
+        `Variable`, `y`.  The `Apply` node constructed by `self.make_node`
+        behind the scenes is available via `y.owner`.
+
+        `PureOp` authors are able to determine which output is returned by this method
+        via the `PureOp.default_output` property., but subclasses are free to override this
+        function and ignore `default_output`.
 
         Parameters
         ----------
-        inputs
-            The Op's inputs, forwarded to the call to `make_node()`.
+        inputs : tuple of Variable
+            The `PureOp`'s inputs.
         kwargs
             Additional keyword arguments to be forwarded to
             `make_node()` *except* for optional argument `return_list` (which
-            defaults to False). If `return_list` is True, then the returned
-            value is always a list. Otherwise it is either a single Variable
+            defaults to `False`). If `return_list` is `True`, then the returned
+            value is always a `list`. Otherwise it is either a single `Variable`
             when the output of `make_node()` contains a single element, or this
             output (unchanged) when it contains multiple elements.
 
+        Returns
+        -------
+        outputs : list of Variable or Variable
+            Either a list of output `Variable`s, or a single `Variable`.
+            This is determined by the number of outputs produced by the
+            `PureOp`, the value of the keyword `return_list`, and the value of
+            the `PureOp.default_output` property.
+
         """
         return_list = kwargs.pop("return_list", False)
         node = self.make_node(*inputs, **kwargs)
 
         if config.compute_test_value != "off":
-            run_perform = True
-
-            # build test input-values
-            storage_map = {}
-            compute_map = {}
-            for i, ins in enumerate(node.inputs):
-                try:
-                    storage_map[ins] = [self._get_test_value(ins)]
-                    compute_map[ins] = [True]
-                except AttributeError:
-                    # no test-value was specified, act accordingly
-                    if config.compute_test_value == "warn":
-                        warnings.warn(
-                            "Warning, Cannot compute test value: input %i (%s) of Op %s missing default value"
-                            % (i, ins, node),
-                            stacklevel=2,
-                        )
-                        run_perform = False
-                    elif config.compute_test_value == "raise":
-                        detailed_err_msg = utils.get_variable_trace_string(ins)
-
-                        raise ValueError(
-                            "Cannot compute test value: input %i (%s) of Op %s missing default value. %s"
-                            % (i, ins, node, detailed_err_msg)
-                        )
-                    elif config.compute_test_value == "ignore":
-                        # silently skip test
-                        run_perform = False
-                    elif config.compute_test_value == "pdb":
-                        import pdb
-
-                        pdb.post_mortem(sys.exc_info()[2])
-                    else:
-                        raise ValueError(
-                            "%s is invalid for option config.compute_test_value"
-                            % config.compute_test_value
-                        )
-
-            # if all inputs have test-values, run the actual op
-            if run_perform:
-                # Original values should not be destroyed:
-                # copy the values of the inputs in destroy_map
-                destroyed_inputs_idx = set()
-                if getattr(node.op, "destroy_map", None):
-                    for i_pos_list in node.op.destroy_map.values():
-                        destroyed_inputs_idx.update(i_pos_list)
-                for inp_idx in destroyed_inputs_idx:
-                    inp = node.inputs[inp_idx]
-                    storage_map[inp] = [storage_map[inp][0].copy()]
-
-                # Prepare storage_map and compute_map for the outputs
-                for o in node.outputs:
-                    storage_map[o] = [None]
-                    compute_map[o] = [False]
-
-                # compute output value once with test inputs to validate graph
-                thunk = node.op.make_thunk(
-                    node, storage_map, compute_map, no_recycling=[]
-                )
-                thunk.inputs = [storage_map[v] for v in node.inputs]
-                thunk.outputs = [storage_map[v] for v in node.outputs]
-
-                required = thunk()
-                assert not required  # We provided all inputs
-
-                for output in node.outputs:
-                    # Check that the output has been computed
-                    assert compute_map[output][0], (output, storage_map[output][0])
-
-                    # add 'test_value' to output tag, so that downstream ops can use these
-                    # numerical values as inputs to their perform method.
-                    output.tag.test_value = storage_map[output][0]
+            compute_test_value(node)
 
         if self.default_output is not None:
             rval = node.outputs[self.default_output]
@@ -704,17 +662,56 @@ class PureOp(object):
 
     # Convenience so that subclass implementers don't have to import utils
     # just to self.add_tag_trace
-    add_tag_trace = staticmethod(utils.add_tag_trace)
+    add_tag_trace = staticmethod(add_tag_trace)
 
-    #########################
-    # Python implementation #
-    #########################
+    def grad(self, inputs, output_grads):
+        """Construct a graph for the gradient with respect to each input variable.
+
+        Each returned `Variable` represents the gradient with respect to that
+        input computed based on the symbolic gradients with respect to each
+        output. If the output is not differentiable with respect to an input,
+        then this method should return an instance of type `NullType` for that
+        input.
+
+        Parameters
+        ----------
+        inputs : list of Variable
+            The input variables.
+        output_grads : list of Variable
+            The gradients of the output variables.
+
+        Returns
+        -------
+        grads : list of Variable
+            The gradients with respect to each `Variable` in `inputs`.
+
+        """
+        raise NotImplementedError()
 
     def L_op(self, inputs, outputs, output_grads):
+        r"""Construct a graph for the L-operator.
+
+        This method is primarily used by `tensor.Lop` and dispatches to
+        `PureOp.grad` by default.
+
+        The *L-operator* computes a *row* vector times the Jacobian. The
+        mathematical relationship is
+        :math:`v \frac{\partial f(x)}{\partial x}`.
+        The *L-operator* is also supported for generic tensors (not only for
+        vectors).
+
+        Parameters
+        ----------
+        inputs : list of Variable
+        outputs : list of Variable
+        output_grads : list of Variable
+
+        """
         return self.grad(inputs, output_grads)
 
     def R_op(self, inputs, eval_points):
-        """
+        """Construct a graph for the R-operator.
+
         This method is primarily used by tensor.Rop
 
         Suppose the op outputs
@@ -737,12 +734,7 @@ class PureOp(object):
                                   eval_points=eval_points)
 
         """
-        raise NotImplementedError(
-            "%s of class %s does not "
-            "implement R_op. If this is a theano op, write to the "
-            "theano-dev mailing list for assistance. If it is your "
-            "own op, implement the R_op method." % (self, self.__class__.__name__)
-        )
+        raise NotImplementedError()
 
     def perform(self, node, inputs, output_storage, params=None):
         """
@@ -751,24 +743,31 @@ class PureOp(object):
 
         Parameters
         ----------
-        node : Apply instance
-            Contains the symbolic inputs and outputs.
-        inputs : list
-            Sequence of inputs (immutable).
-        output_storage : list
-             List of mutable 1-element lists (do not change the length of
-             these lists)
+        node : Apply
+            The symbolic `Apply` node that represents this computation.
+        inputs : Sequence
+            Immutable sequence of non-symbolic/numeric inputs.  These
+            are the values of each `Variable` in `node.inputs`.
+        output_storage : list of list
+            List of mutable single-element lists (do not change the length of
+            these lists).  Each sub-list corresponds to value of each
+            `Variable` in `node.outputs`.  The primary purpose of this method
+            is to set the values of these sub-lists.
+        params : tuple
+            A tuple containing the values of each entry in `__props__`.
 
         Notes
         -----
         The `output_storage` list might contain data. If an element of
-        output_storage is not None, it has to be of the right type,
-        for instance, for a TensorVariable, it has to be a Numpy ndarray,
-        with the right number of dimensions, and the correct dtype.
-        Its shape and stride pattern, can be arbitrary. It not is
-        guaranteed that it was produced by a previous call to impl. It
-        could be allocated by another Op impl is free to reuse it as it
-        sees fit, or to discard it and allocate new memory.
+        output_storage is not `None`, it has to be of the right type, for
+        instance, for a `TensorVariable`, it has to be a NumPy `ndarray`
+        with the right number of dimensions and the correct dtype.
+        Its shape and stride pattern can be arbitrary. It is not
+        guaranteed that such pre-set values were produced by a previous call to
+        this `PureOp.perform`; they could've been allocated by another
+        `PureOp`'s `perform` method.
+        A `PureOp` is free to reuse `output_storage` as it sees fit, or to
+        discard it and allocate new memory.
 
         Raises
         ------
@@ -776,7 +775,7 @@ class PureOp(object):
             The subclass does not override this method.
 
         """
-        raise utils.MethodNotDefined(
+        raise MethodNotDefined(
             "perform",
             type(self),
             self.__class__.__name__,
@@ -785,18 +784,28 @@ class PureOp(object):
         )
 
     def do_constant_folding(self, node):
-        """
-        This allows each op to determine if it wants to be constant
-        folded when all its inputs are constant. This allows it to
-        choose where it puts its memory/speed trade-off. Also, it
-        could make things faster as constants can't be used for inplace
-        operations (see *IncSubtensor).
+        """Determine whether or not constant folding should be performed for the given node.
+
+        This allows each `PureOp` to determine if it wants to be constant
+        folded when all its inputs are constant. This allows it to choose where
+        it puts its memory/speed trade-off. Also, it could make things faster
+        as constants can't be used for in-place operations (see
+        `*IncSubtensor`).
+
+        Parameters
+        ----------
+        node : Apply
+            The node for which the constant folding determination is made.
+
+        Returns
+        -------
+        res : bool
 
         """
         return True
 
 
-class Op(utils.object2, PureOp, CLinkerOp):
+class Op(object2, PureOp, CLinkerOp):
     """
     Convenience class to bundle `PureOp` and `CLinkerOp`.
 
@@ -820,7 +829,7 @@ class Op(utils.object2, PureOp, CLinkerOp):
                 )
             # ParamsType.get_params() will apply filtering to attributes.
             return self.params_type.get_params(self)
-        raise theano.gof.utils.MethodNotDefined("get_params")
+        raise MethodNotDefined("get_params")
 
     def prepare_node(self, node, storage_map, compute_map, impl):
         """
@@ -834,7 +843,6 @@ class Op(utils.object2, PureOp, CLinkerOp):
         good to do so.
 
         """
-        pass
 
     def make_c_thunk(self, node, storage_map, compute_map, no_recycling):
         """Like make_thunk, but will only try to make a C thunk."""
@@ -971,7 +979,7 @@ class Op(utils.object2, PureOp, CLinkerOp):
             )
             try:
                 return self.make_c_thunk(node, storage_map, compute_map, no_recycling)
-            except (NotImplementedError, utils.MethodNotDefined):
+            except (NotImplementedError, MethodNotDefined):
                 # We requested the c code, so don't catch the error.
                 if impl == "c":
                     raise
@@ -1013,23 +1021,20 @@ class Op(utils.object2, PureOp, CLinkerOp):
 
 
 def get_test_value(v):
-    """
-    Extract test value from `v`. Raises AttributeError if there is none.
+    """Get the test value for `v`.
 
     If input `v` is not already a variable, it is turned into one by calling
-    `as_tensor_variable(v)`, so that this function can be applied e.g.
-    on numpy arrays or Python lists and scalars, considering them as constants.
+    `as_tensor_variable(v)`.
 
-    For a Constant, the test value is v.value.
-    For a Shared variable, it is the internal value.
-    For another Variable, it is the content of v.tag.test_value.
+    Raises
+    ------
+    AttributeError if no test value is set.
 
     """
     if not isinstance(v, graph.Variable):
-        v_var = theano.tensor.as_tensor_variable(v)
-    else:
-        v_var = v
-    return PureOp._get_test_value(v_var)
+        v = theano.tensor.as_tensor_variable(v)
+
+    return v.get_test_value()
 
 
 def missing_test_message(msg):
@@ -1050,55 +1055,20 @@ def missing_test_message(msg):
     """
     action = config.compute_test_value
     if action == "raise":
-        raise AttributeError(msg)
+        raise TestValueError(msg)
     elif action == "warn":
         warnings.warn(msg, stacklevel=2)
     else:
         assert action in ["ignore", "off"]
 
 
-def debug_error_message(msg):
-    """
-    Displays a message saying that an error was found in some
-    test_values. Becomes a warning or a ValueError depending on
-    config.compute_test_value.
-
-    """
-    action = config.compute_test_value
-
-    # this message should never be called when the debugger is off
-    assert action != "off"
-
-    if action in ["raise", "ignore"]:
-        raise ValueError(msg)
-    else:
-        assert action == "warn"
-        warnings.warn(msg, stacklevel=2)
-
-
-def debug_assert(condition, msg=None):
-    """
-    Customized assert with options to ignore the assert
-    with just a warning
-    """
-    if msg is None:
-        msg = "debug_assert failed"
-    if not condition:
-        action = config.compute_test_value
-        if action in ["raise", "ignore"]:
-            raise AssertionError(msg)
-        else:
-            assert action == "warn"
-            warnings.warn(msg, stacklevel=2)
-
-
-def get_debug_values(*args):
+def get_test_values(*args):
     """
     Intended use:
 
         for val_1, ..., val_n in get_debug_values(var_1, ..., var_n):
             if some condition on val_1, ..., val_n is not met:
-                debug_error_message("condition was not met")
+                missing_test_message("condition was not met")
 
     Given a list of variables, get_debug_values does one of three things:
 
@@ -1125,13 +1095,13 @@ def get_debug_values(*args):
     for i, arg in enumerate(args):
         try:
             rval.append(get_test_value(arg))
-        except AttributeError:
+        except TestValueError:
             if hasattr(arg, "name") and arg.name is not None:
                 missing_test_message(
-                    "Argument " + str(i) + "('" + arg.name + "') has no test value"
+                    "Argument {} ('{}') has no test value".format(i, arg.name)
                 )
             else:
-                missing_test_message("Argument " + str(i) + " has no test value")
+                missing_test_message("Argument {} has no test value".format(i))
             return []
 
     if len(rval) == 1:
@@ -1259,7 +1229,7 @@ def simple_meth(tag):
         if tag in self.code_sections:
             return self.code_sections[tag]
         else:
-            raise utils.MethodNotDefined("c_" + tag, type(self), type(self).__name__)
+            raise MethodNotDefined("c_" + tag, type(self), type(self).__name__)
 
     f.__name__ = "c_" + tag
     return f
@@ -1273,7 +1243,7 @@ def apply_meth(tag):
             define_macros, undef_macros = self.get_c_macros(node, name)
             return "\n".join(["", define_macros, code, undef_macros])
         else:
-            raise utils.MethodNotDefined("c_" + tag, type(self), type(self).__name__)
+            raise MethodNotDefined("c_" + tag, type(self), type(self).__name__)
 
     f.__name__ = "c_" + tag
     return f
@@ -1293,19 +1263,17 @@ class COp(Op):
     section_re = re.compile(r"^#section ([a-zA-Z0-9_]+)$", re.MULTILINE)
     backward_re = re.compile(r"^THEANO_(APPLY|SUPPORT)_CODE_SECTION$", re.MULTILINE)
     # This is the set of allowed markers
-    SECTIONS = set(
-        [
-            "init_code",
-            "init_code_apply",
-            "init_code_struct",
-            "support_code",
-            "support_code_apply",
-            "support_code_struct",
-            "cleanup_code_struct",
-            "code",
-            "code_cleanup",
-        ]
-    )
+    SECTIONS = {
+        "init_code",
+        "init_code_apply",
+        "init_code_struct",
+        "support_code",
+        "support_code_apply",
+        "support_code_struct",
+        "cleanup_code_struct",
+        "code",
+        "code_cleanup",
+    }
 
     @classmethod
     def get_path(cls, f):
@@ -1360,7 +1328,7 @@ class COp(Op):
         self.func_codes = []
         for func_file in func_files:
             # U (universal) will convert all new lines format to \n.
-            with _open_u(func_file) as f:
+            with open(func_file) as f:
                 self.func_codes.append(f.read())
 
         # If both the old section markers and the new section markers are
@@ -1460,7 +1428,7 @@ class COp(Op):
                             wrapper.types[i].c_element_type(),
                         )
                     )
-                except utils.MethodNotDefined:
+                except MethodNotDefined:
                     pass
             return params
         return []
@@ -1478,7 +1446,7 @@ class COp(Op):
         if "init_code" in self.code_sections:
             return [self.code_sections["init_code"]]
         else:
-            raise utils.MethodNotDefined("c_init_code", type(self), type(self).__name__)
+            raise MethodNotDefined("c_init_code", type(self), type(self).__name__)
 
     c_init_code_apply = apply_meth("init_code_apply")
     c_support_code = simple_meth("support_code")
@@ -1565,10 +1533,10 @@ class COp(Op):
     def get_sub_macros(self, sub):
         define_macros = []
         undef_macros = []
-        define_macros.append("#define FAIL %s" % (self._lquote_macro(sub["fail"]),))
+        define_macros.append("#define FAIL {}".format(self._lquote_macro(sub["fail"])))
         undef_macros.append("#undef FAIL")
         if "params" in sub:
-            define_macros.append("#define PARAMS %s" % (sub["params"],))
+            define_macros.append("#define PARAMS {}".format(sub["params"]))
             undef_macros.append("#undef PARAMS")
 
         return "\n".join(define_macros), "\n".join(undef_macros)
@@ -1600,7 +1568,7 @@ class COp(Op):
                 ["", def_macros, def_sub, op_code, undef_sub, undef_macros]
             )
         else:
-            raise utils.MethodNotDefined(
+            raise MethodNotDefined(
                 "c_init_code_struct", type(self), type(self).__name__
             )
 
@@ -1614,7 +1582,7 @@ class COp(Op):
 
             params = ""
             if "params" in sub:
-                params = ", %s" % (sub["params"],)
+                params = ", {}".format(sub["params"])
 
             # Generate the C code
             return """
@@ -1653,7 +1621,7 @@ class COp(Op):
                     ]
                 )
             else:
-                raise utils.MethodNotDefined("c_code", type(self), type(self).__name__)
+                raise MethodNotDefined("c_code", type(self), type(self).__name__)
 
     def c_code_cleanup(self, node, name, inputs, outputs, sub):
         """
@@ -1678,6 +1646,4 @@ class COp(Op):
                 ]
             )
         else:
-            raise utils.MethodNotDefined(
-                "c_code_cleanup", type(self), type(self).__name__
-            )
+            raise MethodNotDefined("c_code_cleanup", type(self), type(self).__name__)
