@@ -1,17 +1,13 @@
-import sys
+import hashlib
 import linecache
+import sys
 import traceback
-
-import numpy as np
-
-from six import integer_types, string_types, with_metaclass
-from six.moves import StringIO
+from io import StringIO
 
 from theano import config
-from theano.compat import PY3
 
 
-def simple_extract_stack(f=None, limit=None, skips=[]):
+def simple_extract_stack(f=None, limit=None, skips=None):
     """This is traceback.extract_stack from python 2.7 with this change:
 
     - Comment the update of the cache.
@@ -27,6 +23,9 @@ def simple_extract_stack(f=None, limit=None, skips=[]):
         When we find one level that isn't skipped, we stop skipping.
 
     """
+    if skips is None:
+        skips = []
+
     if f is None:
         try:
             raise ZeroDivisionError
@@ -104,8 +103,8 @@ def add_tag_trace(thing, user_line=None):
         "theano\\scalar\\basic.py",
         "theano/sandbox/",
         "theano\\sandbox\\",
-        "theano/scan_module/",
-        "theano\\scan_module\\",
+        "theano/scan/",
+        "theano\\scan\\",
         "theano/sparse/",
         "theano\\sparse\\",
         "theano/typed_list/",
@@ -156,6 +155,10 @@ def hashtype(self):
 undef = object()
 
 
+class TestValueError(Exception):
+    """Base exception class for all test value errors."""
+
+
 class MethodNotDefined(Exception):
     """
     To be raised by functions defined as part of an interface.
@@ -165,8 +168,6 @@ class MethodNotDefined(Exception):
 
     """
 
-    pass
-
 
 class MetaObject(type):
     def __new__(cls, name, bases, dct):
@@ -174,7 +175,7 @@ class MetaObject(type):
         if props is not None:
             if not isinstance(props, tuple):
                 raise TypeError("__props__ has to be a tuple")
-            if not all(isinstance(p, string_types) for p in props):
+            if not all(isinstance(p, str) for p in props):
                 raise TypeError("elements of __props__ have to be strings")
 
             def _props(self):
@@ -193,7 +194,7 @@ class MetaObject(type):
                 least all the original props.
 
                 """
-                return dict([(a, getattr(self, a)) for a in props])
+                return {a: getattr(self, a) for a in props}
 
             dct["_props_dict"] = _props_dict
 
@@ -217,14 +218,16 @@ class MetaObject(type):
                 if len(props) == 0:
 
                     def __str__(self):
-                        return "%s" % (self.__class__.__name__,)
+                        return "{}".format(self.__class__.__name__)
 
                 else:
 
                     def __str__(self):
-                        return "%s{%s}" % (
+                        return "{}{{{}}}".format(
                             self.__class__.__name__,
-                            ", ".join("%s=%r" % (p, getattr(self, p)) for p in props),
+                            ", ".join(
+                                "{}={!r}".format(p, getattr(self, p)) for p in props
+                            ),
                         )
 
                 dct["__str__"] = __str__
@@ -232,14 +235,14 @@ class MetaObject(type):
         return type.__new__(cls, name, bases, dct)
 
 
-class object2(with_metaclass(MetaObject, object)):
+class object2(metaclass=MetaObject):
     __slots__ = []
 
     def __ne__(self, other):
         return not self == other
 
 
-class scratchpad(object):
+class Scratchpad:
     def clear(self):
         self.__dict__.clear()
 
@@ -256,7 +259,24 @@ class scratchpad(object):
     def info(self):
         print("<theano.gof.utils.scratchpad instance at %i>" % id(self))
         for k, v in self.__dict__.items():
-            print("  %s: %s" % (k, v))
+            print("  {}: {}".format(k, v))
+
+
+class ValidatingScratchpad(Scratchpad):
+    """This `Scratchpad` validates attribute values."""
+
+    def __init__(self, attr, attr_filter):
+        super().__init__()
+
+        object.__setattr__(self, "attr", attr)
+        object.__setattr__(self, "attr_filter", attr_filter)
+
+    def __setattr__(self, attr, obj):
+
+        if getattr(self, "attr", None) == attr:
+            obj = self.attr_filter(obj)
+
+        return object.__setattr__(self, attr, obj)
 
 
 class D:
@@ -305,7 +325,7 @@ def deprecated(filename, msg=""):
 
         def g(*args, **kwargs):
             if printme[0]:
-                print("WARNING: %s.%s deprecated. %s" % (filename, f.__name__, msg))
+                print("WARNING: {}.{} deprecated. {}".format(filename, f.__name__, msg))
                 printme[0] = False
             return f(*args, **kwargs)
 
@@ -379,7 +399,7 @@ def toposort(prereqs_d):
     for x, prereqs in prereqs_d.items():
         for prereq in prereqs:
             postreqs_d.setdefault(prereq, set()).add(x)
-    next = set([k for k in prereqs_d if not prereqs_d[k]])
+    next = {k for k in prereqs_d if not prereqs_d[k]}
     while next:
         bases = next
         next = set()
@@ -424,7 +444,7 @@ RETRY = Keyword("RETRY", False)
 FAILURE = Keyword("FAILURE", False)
 
 
-simple_types = integer_types + string_types + (float, bool, None.__class__, Keyword)
+simple_types = (int, str, float, bool, type(None), Keyword)
 
 
 ANY_TYPE = Keyword("ANY_TYPE")
@@ -576,28 +596,14 @@ def remove(predicate, coll):
     return [x for x in coll if not predicate(x)]
 
 
-if PY3:
-    import hashlib
-
-    def hash_from_code(msg):
-        # hashlib.sha256() requires an object that supports buffer interface,
-        # but Python 3 (unicode) strings don't.
-        if isinstance(msg, str):
-            msg = msg.encode()
-        # Python 3 does not like module names that start with
-        # a digit.
-        return "m" + hashlib.sha256(msg).hexdigest()
-
-
-else:
-    import hashlib
-
-    def hash_from_code(msg):
-        try:
-            return hashlib.sha256(msg).hexdigest()
-        except TypeError:
-            assert isinstance(msg, np.ndarray)
-            return hashlib.sha256(np.getbuffer(msg)).hexdigest()
+def hash_from_code(msg):
+    # hashlib.sha256() requires an object that supports buffer interface,
+    # but Python 3 (unicode) strings don't.
+    if isinstance(msg, str):
+        msg = msg.encode()
+    # Python 3 does not like module names that start with
+    # a digit.
+    return "m" + hashlib.sha256(msg).hexdigest()
 
 
 def hash_from_file(file_path):
