@@ -6,19 +6,18 @@ VM was a better name at some point.
 
 """
 import logging
+import platform
 import sys
 import time
 import warnings
-import platform
-
-import theano.gof.cmodule
-
 from collections import defaultdict
 
-from theano.configparser import config, _config_var_list
+import theano.gof.cmodule
+from theano.configparser import _config_var_list, config
 
 from . import link
 
+
 logger = logging.getLogger(__name__)
 
 
@@ -31,8 +30,8 @@ def calculate_reallocate_info(order, fgraph, storage_map, compute_map_re, depend
     for var in fgraph.variables:
         viewed_by[var] = []
     view_of = {}
-    pre_allocated = set([])
-    allocated = set([])
+    pre_allocated = set()
+    allocated = set()
 
     for idx in range(len(order)):
         node = order[idx]
@@ -121,7 +120,7 @@ def calculate_reallocate_info(order, fgraph, storage_map, compute_map_re, depend
     return reallocated_info
 
 
-class VM(object):
+class VM:
     """
     A VM object's __call__ method evaluates a Theano program.
 
@@ -274,7 +273,7 @@ class LoopGC(VM):
     """
 
     def __init__(self, nodes, thunks, pre_call_clear, post_thunk_clear):
-        super(LoopGC, self).__init__(nodes, thunks, pre_call_clear)
+        super().__init__(nodes, thunks, pre_call_clear)
         self.post_thunk_clear = post_thunk_clear
         # Some other part of Theano query that information
         self.allow_gc = True
@@ -354,7 +353,7 @@ class Stack(VM):
         callback=None,
         callback_input=None,
     ):
-        super(Stack, self).__init__(nodes, thunks, pre_call_clear)
+        super().__init__(nodes, thunks, pre_call_clear)
 
         self.allow_gc = allow_gc
         self.message = ""
@@ -713,7 +712,6 @@ except (OSError, theano.gof.cmodule.MissingGXX) as e:
     assert not [x for x in _config_var_list if x.fullname == "linker"][
         0
     ].default.startswith("cvm"), e
-    pass
 
 
 class VM_Linker(link.LocalLinker):
@@ -924,7 +922,7 @@ class VM_Linker(link.LocalLinker):
             if self.use_cloop and (
                 self.callback is not None or self.callback_input is not None
             ):
-                logger.warn("CVM does not support callback, using Stack VM.")
+                logger.warning("CVM does not support callback, using Stack VM.")
             if self.use_cloop and config.profile_memory:
                 warnings.warn("CVM does not support memory profile, using Stack VM.")
             if not self.use_cloop and self.allow_partial_eval:
@@ -1125,7 +1123,7 @@ class VM_Linker(link.LocalLinker):
             compute_map_re[var][0] = 1
 
         if getattr(fgraph.profile, "dependencies", None):
-            dependencies = getattr(fgraph.profile, "dependencies")
+            dependencies = fgraph.profile.dependencies
         else:
             dependencies = self.compute_gc_dependencies(storage_map)
 
