@@ -1,23 +1,25 @@
 from theano import Apply, Op
 from theano.tensor.extra_ops import CumOp
 
+
 try:
     from pygpu import gpuarray
 except ImportError:
     pass
 
-from .basic_ops import (
-    as_gpuarray_variable,
-    GpuKernelBase,
-    Kernel,
-    GpuReshape,
-    infer_context_name,
-    gpuarray_helper_inc_dir,
-)
-from .opt import register_opt, op_lifter, register_opt2
-from .type import gpu_context_type
-from theano.gof import ParamsType
 import theano.scalar as scalar
+from theano.gof import ParamsType
+
+from .basic_ops import (
+    GpuKernelBase,
+    GpuReshape,
+    Kernel,
+    as_gpuarray_variable,
+    gpuarray_helper_inc_dir,
+    infer_context_name,
+)
+from .opt import op_lifter, register_opt, register_opt2
+from .type import gpu_context_type
 
 
 class GpuCumOp(GpuKernelBase, Op):
@@ -71,7 +73,7 @@ class GpuCumOp(GpuKernelBase, Op):
             )
 
         if self.axis >= x.ndim or self.axis < -x.ndim:
-            raise ValueError("axis(={0}) out of bounds".format(self.axis))
+            raise ValueError("axis(={}) out of bounds".format(self.axis))
         return Apply(self, [x], [x.type()])
 
     def gpu_kernels(self, node, nodename):
@@ -498,7 +500,7 @@ class GpuCumOp(GpuKernelBase, Op):
         """
             % locals()
         )
-        return super(GpuCumOp, self).c_support_code_struct(node, nodename) + code
+        return super().c_support_code_struct(node, nodename) + code
 
 
 # GpuCumsumOp exists only to serve backward compatibility.
