@@ -1,15 +1,24 @@
+from io import StringIO
+
 import numpy as np
-import theano.tensor as T
 
-from six import integer_types
-from six.moves import StringIO
-
-from theano import tensor, gof, Op
+import theano.tensor as tt
+from theano import Op, gof
 from theano.gof import ParamsType
 from theano.gradient import grad_not_implemented
-from theano.tensor.subtensor import IncSubtensor, Subtensor, get_idx_list
+from theano.scalar import bool as bool_t
+from theano.scalar import int32 as int_t
+from theano.scalar import uint32 as size_t
 from theano.tensor import AllocDiag
-from theano.scalar import bool as bool_t, int32 as int_t, uint32 as size_t
+from theano.tensor.subtensor import (
+    AdvancedIncSubtensor,
+    AdvancedSubtensor,
+    AdvancedSubtensor1,
+    IncSubtensor,
+    Subtensor,
+    get_idx_list,
+)
+
 
 try:
     import pygpu
@@ -17,16 +26,17 @@ try:
 except ImportError:
     pass
 
-from .type import GpuArrayType, gpu_context_type
-from .basic_ops import (
-    as_gpuarray_variable,
-    HideC,
+from theano.gpuarray.basic_ops import (
     GpuKernelBase,
+    HideC,
     Kernel,
+    as_gpuarray_variable,
+    gpu_contiguous,
     gpuarray_helper_inc_dir,
     infer_context_name,
-    gpu_contiguous,
 )
+from theano.gpuarray.type import GpuArrayType, gpu_context_type
+
 
 iadd_reg = {}
 
@@ -52,7 +62,7 @@ class GpuSubtensor(HideC, Subtensor):
 
     def make_node(self, x, *inputs):
         ctx_name = infer_context_name(x)
-        rval = tensor.Subtensor.make_node(self, x, *inputs)
+        rval = Subtensor.make_node(self, x, *inputs)
         otype = GpuArrayType(
             dtype=rval.outputs[0].type.dtype,
             broadcastable=rval.outputs[0].type.broadcastable,
@@ -147,7 +157,7 @@ class GpuSubtensor(HideC, Subtensor):
         def fix_idx(idx):
             if idx is None:
                 return "0", 1
-            elif isinstance(idx, (np.integer, integer_types)):
+            elif isinstance(idx, (np.integer, int)):
                 return str(idx), 0
             elif isinstance(idx, gof.Type):
                 return indices.pop(0), 0
@@ -186,7 +196,7 @@ class GpuSubtensor(HideC, Subtensor):
             else:
                 if isinstance(idx, gof.Type):
                     start = indices.pop(0)
-                elif isinstance(idx, (np.integer, integer_types)):
+                elif isinstance(idx, (np.integer, int)):
                     start = idx
                 else:
                     assert 0, idx
@@ -226,7 +236,7 @@ class GpuIncSubtensor(IncSubtensor):
     -----
     The optimization to make this inplace is in tensor/opt.
     The same optimization handles IncSubtensor and GpuIncSubtensor.
-    This Op has c_code too; it inherits tensor.IncSubtensor's c_code.
+    This Op has c_code too; it inherits IncSubtensor's c_code.
     The helper methods like :meth:`do_type_checking`,
     :meth:`copy_of_x`, etc. specialize the c_code for this Op.
 
@@ -239,7 +249,7 @@ class GpuIncSubtensor(IncSubtensor):
         ctx_name = infer_context_name(x, y)
         x = as_gpuarray_variable(x, ctx_name)
         y = as_gpuarray_variable(y, ctx_name)
-        rval = tensor.IncSubtensor.make_node(self, x, y, *inputs)
+        rval = IncSubtensor.make_node(self, x, y, *inputs)
         ret = gof.Apply(self, [x, y] + rval.inputs[2:], [x.type()])
         return ret
 
@@ -444,13 +454,13 @@ int sub_setarray(GpuArray *dst, GpuArray *src) {
         )
 
     def c_code_cache_version(self):
-        parent_version = super(GpuIncSubtensor, self).c_code_cache_version()
+        parent_version = super().c_code_cache_version()
         if not parent_version:
             return
         return parent_version + (10,)
 
 
-class GpuAdvancedSubtensor1(HideC, tensor.AdvancedSubtensor1):
+class GpuAdvancedSubtensor1(HideC, AdvancedSubtensor1):
     """
     AdvancedSubrensor1 on the GPU.
     """
@@ -461,11 +471,11 @@ class GpuAdvancedSubtensor1(HideC, tensor.AdvancedSubtensor1):
         ctx_name = infer_context_name(x, ilist)
         x_ = as_gpuarray_variable(x, ctx_name)
 
-        ilist__ = tensor.as_tensor_variable(ilist)
-        if ilist__.type.dtype not in tensor.integer_dtypes:
+        ilist__ = tt.as_tensor_variable(ilist)
+        if ilist__.type.dtype not in tt.integer_dtypes:
             raise TypeError("index must be integers")
         if ilist__.type.dtype != "int64":
-            ilist__ = tensor.cast(ilist__, "int64")
+            ilist__ = tt.cast(ilist__, "int64")
 
         ilist_ = gpu_contiguous(as_gpuarray_variable(ilist__, ctx_name))
 
@@ -566,7 +576,7 @@ def check_and_convert_boolean_masks(input, idx_list):
     return out_idx_list
 
 
-class BaseGpuAdvancedSubtensor(object):
+class BaseGpuAdvancedSubtensor:
     def perform(self, node, inputs, out_):
         (out,) = out_
         x = inputs[0]
@@ -676,14 +686,14 @@ class BaseGpuAdvancedSubtensor(object):
         out[0] = o
 
 
-class GpuAdvancedSubtensor(HideC, BaseGpuAdvancedSubtensor, tensor.AdvancedSubtensor):
+class GpuAdvancedSubtensor(HideC, BaseGpuAdvancedSubtensor, AdvancedSubtensor):
     """
     AdvancedSubtensor on the GPU.
     """
 
     def make_node(self, x, *inputs):
         ctx_name = infer_context_name(x)
-        rval = tensor.AdvancedSubtensor.make_node(self, x, *inputs)
+        rval = AdvancedSubtensor.make_node(self, x, *inputs)
         otype = GpuArrayType(
             dtype=rval.outputs[0].type.dtype,
             broadcastable=rval.outputs[0].type.broadcastable,
@@ -693,7 +703,7 @@ class GpuAdvancedSubtensor(HideC, BaseGpuAdvancedSubtensor, tensor.AdvancedSubte
         return gof.Apply(self, [x] + rval.inputs[1:], [otype()])
 
 
-class BaseGpuAdvancedIncSubtensor(object):
+class BaseGpuAdvancedIncSubtensor:
     def perform(self, node, inp, out_):
         (out,) = out_
         x = inp[0]
@@ -809,9 +819,7 @@ class BaseGpuAdvancedIncSubtensor(object):
         out[0] = x_
 
 
-class GpuAdvancedIncSubtensor(
-    HideC, BaseGpuAdvancedIncSubtensor, tensor.AdvancedIncSubtensor
-):
+class GpuAdvancedIncSubtensor(HideC, BaseGpuAdvancedIncSubtensor, AdvancedIncSubtensor):
     """
     Implement AdvancedIncSubtensor on the gpu.
 
@@ -819,7 +827,7 @@ class GpuAdvancedIncSubtensor(
 
     def make_node(self, x, y, *inputs):
         ctx_name = infer_context_name(x, y)
-        rval = tensor.AdvancedIncSubtensor.make_node(self, x, y, *inputs)
+        rval = AdvancedIncSubtensor.make_node(self, x, y, *inputs)
         otype = GpuArrayType(
             dtype=rval.outputs[0].type.dtype,
             broadcastable=rval.outputs[0].type.broadcastable,
@@ -863,11 +871,11 @@ class GpuAdvancedIncSubtensor1(Op):
         ctx_name = infer_context_name(x, y)
         x_ = as_gpuarray_variable(x, ctx_name)
         y_ = as_gpuarray_variable(y, ctx_name)
-        ilist_ = tensor.as_tensor_variable(ilist)
+        ilist_ = tt.as_tensor_variable(ilist)
 
         assert x_.type.ndim >= y_.type.ndim
 
-        if ilist_.type.dtype not in tensor.integer_dtypes:
+        if ilist_.type.dtype not in tt.integer_dtypes:
             raise TypeError("index must be integers")
         if ilist_.type.ndim != 1:
             raise TypeError("index must be vector")
@@ -1106,7 +1114,7 @@ class GpuAdvancedIncSubtensor1_dev20(GpuKernelBase, HideC, GpuAdvancedIncSubtens
 
         assert x_.type.ndim >= y_.type.ndim
 
-        if ilist_.type.dtype not in tensor.integer_dtypes:
+        if ilist_.type.dtype not in tt.integer_dtypes:
             raise TypeError("index must be integers")
         if ilist_.type.ndim != 1:
             raise TypeError("index must be vector")
@@ -1125,7 +1133,7 @@ class GpuAdvancedIncSubtensor1_dev20(GpuKernelBase, HideC, GpuAdvancedIncSubtens
         return gof.Apply(self, [x_, y_, ilist_], [x_.type()])
 
     def perform(self, node, inp, out, params):
-        return super(GpuAdvancedIncSubtensor1_dev20, self).perform(node, inp, out)
+        return super().perform(node, inp, out)
 
     def c_code_cache_version(self):
         return (14,)
@@ -1261,9 +1269,7 @@ if (GpuArray_vector_add_fast(%(out)s, %(y)s, %(ind)s, %(params)s->set_instead_of
 
     def c_support_code_struct(self, node, nodename):
         return (
-            super(GpuAdvancedIncSubtensor1_dev20, self).c_support_code_struct(
-                node, nodename
-            )
+            super().c_support_code_struct(node, nodename)
             + """
         int GpuArray_vector_add_fast(PyGpuArrayObject* py_self,
                                      PyGpuArrayObject* py_other,
@@ -1437,11 +1443,11 @@ class GpuExtractDiag(Op):
         # The following logic is inspired by C code of PyArray_Diagonal().
         offset = self.offset
         if offset > 0:
-            diag_size = T.clip(dim2 - offset, 0, dim1)
+            diag_size = tt.clip(dim2 - offset, 0, dim1)
         elif offset < 0:
-            diag_size = T.clip(dim1 + offset, 0, dim2)
+            diag_size = tt.clip(dim1 + offset, 0, dim2)
         else:
-            diag_size = T.minimum(dim1, dim2)
+            diag_size = tt.minimum(dim1, dim2)
         out_shape.append(diag_size)
         return [tuple(out_shape)]
 
