@@ -1,11 +1,11 @@
-from optparse import OptionParser
 import sys
 import time
+from optparse import OptionParser
 
 import numpy as np
 
 import theano
-import theano.tensor as T
+import theano.tensor as tt
 
 
 parser = OptionParser(
@@ -42,11 +42,11 @@ def evalTime(f, v, script=False, loops=1000):
 
 
 def ElemwiseOpTime(N, script=False, loops=1000):
-    x = T.vector("x")
+    x = tt.vector("x")
     np.random.seed(1235)
     v = np.random.random(N).astype(theano.config.floatX)
     f = theano.function([x], 2 * x + x * x)
-    f1 = theano.function([x], T.tanh(x))
+    f1 = theano.function([x], tt.tanh(x))
     if not script:
         if theano.config.openmp:
             print("With openmp:")
@@ -67,5 +67,5 @@ if __name__ == "__main__":
     (cheapTime, costlyTime) = ElemwiseOpTime(N=options.N, script=options.script)
 
     if options.script:
-        sys.stdout.write("%2.9f %2.9f\n" % (cheapTime, costlyTime))
+        sys.stdout.write("{:2.9f} {:2.9f}\n".format(cheapTime, costlyTime))
         sys.stdout.flush()
