@@ -2,10 +2,9 @@
 
 
 import collections
-import operator
 import functools
-
-from theano.compat import Mapping
+import operator
+from collections.abc import Mapping
 
 
 class frozendict(Mapping):
@@ -36,7 +35,7 @@ class frozendict(Mapping):
         return len(self._dict)
 
     def __repr__(self):
-        return "<%s %r>" % (self.__class__.__name__, self._dict)
+        return "<{} {!r}>".format(self.__class__.__name__, self._dict)
 
     def __hash__(self):
         if self._hash is None:
