@@ -16,25 +16,23 @@ P. L'Ecuyer and R. Simard and E. Jack Chen and W. David Kelton, An Object-Orient
 import warnings
 
 import numpy as np
-from six import integer_types, string_types
-
 
 import theano
-from theano import Op, Apply, shared, config, Variable
-from theano import gradient, function
+from theano import Apply, Op, Variable, config, function, gradient, shared, tensor
+from theano.compile import optdb
+from theano.gof import ParamsType, local_optimizer
 from theano.gradient import undefined_grad
-from theano import tensor
+from theano.scalar import bool as bool_t
+from theano.scalar import int32 as int_t
 from theano.tensor import (
     TensorType,
     as_tensor_variable,
-    get_vector_length,
     cast,
+    get_vector_length,
     opt,
     scal,
 )
-from theano.compile import optdb
-from theano.gof import local_optimizer, ParamsType
-from theano.scalar import bool as bool_t, int32 as int_t
+
 from . import multinomial
 
 
@@ -349,7 +347,7 @@ class mrg_uniform_base(Op):
             s = "inplace"
         else:
             s = "no_inplace"
-        return self.__class__.__name__ + "{%s,%s}" % (self.output_type, s)
+        return self.__class__.__name__ + "{{{},{}}}".format(self.output_type, s)
 
     def grad(self, inputs, ograd):
         return [
@@ -533,7 +531,7 @@ class mrg_uniform(mrg_uniform_base):
         assert isinstance(node.inputs[0].type, TensorType)
         if self.output_type.dtype == "float16":
             # C code is not tested, fall back to Python
-            super(mrg_uniform, self).c_code(node, name, inp, out, sub)
+            super().c_code(node, name, inp, out, sub)
         return """
         //////// <code generated by mrg_uniform>
         npy_int64 odims_i;
@@ -673,9 +671,7 @@ def guess_n_streams(size, warn=False):
     # TODO: a smart way of choosing the number of streams, see #612.
     # Note that this code was moved out of `MRG_RandomStreams` so that it can
     # be easily accessed from tests, where we want to disable the warning.
-    if isinstance(size, (tuple, list)) and all(
-        [isinstance(i, integer_types) for i in size]
-    ):
+    if isinstance(size, (tuple, list)) and all([isinstance(i, int) for i in size]):
         # We can make a guess.
         r = 1
         for s in size:
@@ -705,7 +701,7 @@ def guess_n_streams(size, warn=False):
         return 60 * 256
 
 
-class MRG_RandomStreams(object):
+class MRG_RandomStreams:
     """
     Module component with similar interface to numpy.random
     (numpy.random.RandomState).
@@ -731,7 +727,7 @@ class MRG_RandomStreams(object):
         # by this RandomStreams.
         self.state_updates = []
 
-        super(MRG_RandomStreams, self).__init__()
+        super().__init__()
 
         # Needed to reset the streams.
         self.default_instance_seed = seed
@@ -740,7 +736,7 @@ class MRG_RandomStreams(object):
 
     def set_rstate(self, seed):
         # TODO : need description for method, parameter
-        if isinstance(seed, integer_types):
+        if isinstance(seed, int):
             if seed == 0:
                 raise ValueError("seed should not be 0", seed)
             elif seed >= M2:
@@ -811,7 +807,7 @@ class MRG_RandomStreams(object):
         and they are spaced by 2**72 samples.
 
         """
-        assert isinstance(dtype, string_types)
+        assert isinstance(dtype, str)
         assert n_streams < 2 ** 72
         assert n_streams > 0
         rval = np.zeros((n_streams, 6), dtype="int32")
@@ -897,12 +893,8 @@ class MRG_RandomStreams(object):
 
         if isinstance(size, tuple):
             msg = "size must be a tuple of int or a Theano variable"
-            assert all(
-                [isinstance(i, (np.integer, integer_types, Variable)) for i in size]
-            ), msg
-            if any(
-                [isinstance(i, (np.integer, integer_types)) and i <= 0 for i in size]
-            ):
+            assert all([isinstance(i, (np.integer, int, Variable)) for i in size]), msg
+            if any([isinstance(i, (np.integer, int)) and i <= 0 for i in size]):
                 raise ValueError(
                     "The specified size contains a dimension with value <= 0", size
                 )
@@ -995,7 +987,7 @@ class MRG_RandomStreams(object):
         pvals = as_tensor_variable(pvals)
         pvals = undefined_grad(pvals)
         if size is not None:
-            if any([isinstance(i, integer_types) and i <= 0 for i in size]):
+            if any([isinstance(i, int) and i <= 0 for i in size]):
                 raise ValueError(
                     "The specified size contains a dimension with value <= 0", size
                 )
@@ -1018,7 +1010,7 @@ class MRG_RandomStreams(object):
             return op(pvals, unis, n_samples)
         else:
             raise NotImplementedError(
-                ("MRG_RandomStreams.multinomial only" " implemented for pvals.ndim = 2")
+                "MRG_RandomStreams.multinomial only" " implemented for pvals.ndim = 2"
             )
 
     def choice(
@@ -1327,7 +1319,7 @@ def _check_size(size):
             raise ValueError(
                 "Theano variable must have 1 dimension to be a valid size.", size
             )
-    elif isinstance(size, (np.integer, integer_types)):
+    elif isinstance(size, (np.integer, int)):
         return tensor.constant([size], ndim=1)
     elif not isinstance(size, (tuple, list)):
         raise ValueError("Size must be a int, tuple, list or Theano variable.", size)
@@ -1337,7 +1329,7 @@ def _check_size(size):
         if isinstance(i, theano.Variable):
             if i.ndim != 0:
                 raise ValueError("Non-scalar Theano variable in size", size, i)
-        elif isinstance(i, (np.integer, integer_types)):
+        elif isinstance(i, (np.integer, int)):
             if i <= 0:
                 raise ValueError(
                     "Non-positive dimensions not allowed in size.", size, i
