@@ -1,65 +1,20 @@
 import numpy as np
-
-import theano
 import scipy.sparse
 
+import theano
 from theano import gof, tensor
-from theano.tensor import discrete_dtypes, float_dtypes
-from theano.tensor.opt import register_specialize
 from theano.sparse.basic import (
-    as_sparse_variable,
-    SparseType,
-    add_s_s,
-    neg,
-    mul_s_s,
-    mul_s_d,
-    dot,
-    CSMProperties,
-    CSM,
-    _is_sparse_variable,
-    _is_dense_variable,
-    CSC,
-    CSR,
-    csm_properties,
-    csm_data,
-    csm_indices,
-    csm_indptr,
-    csm_shape,
-    _is_sparse,
-    # To maintain compatibility
     Remove0,
+    SparseType,
+    _is_sparse,
+    as_sparse_variable,
     remove0,
-    Cast,
-    bcast,
-    wcast,
-    icast,
-    lcast,
-    fcast,
-    dcast,
-    ccast,
-    zcast,
-    HStack,
-    hstack,
-    VStack,
-    vstack,
-    AddSSData,
-    add_s_s_data,
-    MulSV,
-    mul_s_v,
-    structured_monoid,
-    structured_sigmoid,
-    structured_exp,
-    structured_log,
-    structured_pow,
-    structured_minimum,
-    structured_maximum,
-    structured_add,
-    StructuredAddSV,
-    structured_add_s_v,
-    SamplingDot,
-    sampling_dot,
 )
 
+# Also for compatibility
+from theano.tensor import discrete_dtypes, float_dtypes
+
+
 # Probability Ops are currently back in sandbox, because they do not respect
 # Theano's Op contract, as their behaviour is not reproducible: calling
 # the perform() method twice with the same argument will yield different
@@ -68,24 +23,6 @@ from theano.sparse.basic import (
 #    Multinomial, multinomial, Poisson, poisson,
 #    Binomial, csr_fbinomial, csc_fbinomial, csr_dbinomial, csc_dbinomial)
 
-# Also for compatibility
-from theano.sparse.opt import (
-    MulSDCSC,
-    mul_s_d_csc,
-    MulSDCSR,
-    mul_s_d_csr,
-    MulSVCSR,
-    mul_s_v_csr,
-    StructuredAddSVCSR,
-    structured_add_s_v_csr,
-    SamplingDotCSR,
-    sampling_dot_csr,
-    local_mul_s_d,
-    local_mul_s_v,
-    local_structured_add_s_v,
-    local_sampling_dot_csr,
-)
-
 
 # Alias to maintain compatibility
 EliminateZeros = Remove0
