@@ -1,15 +1,29 @@
+# import theano.tensor.basic as tt
+
 from theano import config
 from theano.gof.params_type import ParamsType
 from theano.scalar import bool as bool_t
+
+# Work-around for Python 3.6 issue that prevents `import theano.tensor as tt`
+from theano.tensor import basic as tt
+from theano.tensor.blas import (
+    Gemv,
+    Ger,
+    blas_header_text,
+    blas_header_version,
+    blas_optdb,
+    gemv_inplace,
+    gemv_no_inplace,
+    ger,
+    ger_destructive,
+    ldflags,
+    local_optimizer,
+    optdb,
+)
 from theano.tensor.opt import in2out
-from theano.tensor.blas import ldflags, blas_header_text, blas_header_version
-from theano.tensor.blas import blas_optdb, optdb, local_optimizer
-from theano.tensor.blas import Ger, ger, ger_destructive
-from theano.tensor.blas import Gemv, gemv_inplace, gemv_no_inplace
-from theano.tensor import basic as T
 
 
-class BaseBLAS(object):
+class BaseBLAS:
     def c_libraries(self):
         return ldflags()
 
@@ -603,7 +617,7 @@ class CGemv(BaseBLAS, Gemv):
     )
 
     def __init__(self, inplace):
-        super(CGemv, self).__init__(inplace)
+        super().__init__(inplace)
 
     def c_code(self, node, name, inp, out, sub):
         y, alpha, A, x, beta = inp
@@ -706,10 +720,10 @@ def make_c_gemv_destructive(node):
         dest = inputs[0]
         if (
             dest.owner
-            and isinstance(dest.owner.op, T.AllocEmpty)
+            and isinstance(dest.owner.op, tt.AllocEmpty)
             and len(dest.clients) > 1
         ):
-            inputs[0] = T.AllocEmpty(dest.dtype)(*dest.owner.inputs)
+            inputs[0] = tt.AllocEmpty(dest.dtype)(*dest.owner.inputs)
 
         return [cgemv_inplace(*inputs)]
 
