@@ -6,14 +6,15 @@ ourselves into the C code.
 """
 
 import logging
-import textwrap
-import sys
 import os
+import sys
+import textwrap
 from os.path import dirname
 
 from theano import config
 from theano.gof.cmodule import GCC_compiler
 
+
 _logger = logging.getLogger("theano.tensor.blas")
 
 
@@ -769,7 +770,7 @@ def blas_header_text():
                 "precision": "d",
             }
         if not common_code or not template_code:
-            raise IOError(
+            raise OSError(
                 "Unable to load NumPy implementation of BLAS functions from C source files."
             )
         blas_code += common_code
