@@ -1,15 +1,15 @@
 import logging
 import warnings
-import numpy as np
-
 from functools import partial
 
+import numpy as np
+
 import theano
-from theano.tensor import as_tensor_variable
-from theano.gof import Op, Apply
+from theano.gof import Apply, Op
 from theano.gradient import DisconnectedType
 from theano.tensor import basic as tensor
-from theano.tensor.basic import ExtractDiag
+from theano.tensor.basic import ExtractDiag, as_tensor_variable
+
 
 logger = logging.getLogger(__name__)
 
@@ -663,17 +663,43 @@ class lstsq(Op):
 
 
 def matrix_power(M, n):
-    """
+    r"""
     Raise a square matrix to the (integer) power n.
+    This implementation uses exponentiation by squaring which is
+    significantly faster than the naive implementation.
+    The time complexity for exponentiation by squaring is
+    :math: `\mathcal{O}((n \log M)^k)`
 
     Parameters
     ----------
     M : Tensor variable
     n : Python int
     """
-    result = 1
-    for i in range(n):
-        result = theano.dot(result, M)
+    if n < 0:
+        M = pinv(M)
+        n = abs(n)
+
+    # Shortcuts when 0 < n <= 3
+    if n == 0:
+        return tensor.eye(M.shape[-2])
+
+    elif n == 1:
+        return M
+
+    elif n == 2:
+        return theano.tensor.dot(M, M)
+
+    elif n == 3:
+        return theano.tensor.dot(theano.tensor.dot(M, M), M)
+
+    result = z = None
+
+    while n > 0:
+        z = M if z is None else theano.tensor.dot(z, z)
+        n, bit = divmod(n, 2)
+        if bit:
+            result = z if result is None else theano.tensor.dot(result, z)
+
     return result
 
 
