@@ -1,17 +1,18 @@
-import os
 import logging
-
-from six import integer_types
+import os
 
 import theano
-from theano import Apply
 from theano import gof
-from theano.gof import ParamsType, EnumList
+from theano.gof.graph import Apply
+from theano.gof.params_type import ParamsType
+from theano.gof.type import EnumList
 from theano.scalar import int64
-from theano.tensor import as_tensor_variable, TensorType
-from theano.tensor.nnet.abstract_conv import get_conv_output_shape
 from theano.tensor import blas_headers
-from theano.tensor.blas import ldflags, blas_header_version
+from theano.tensor.basic import as_tensor_variable
+from theano.tensor.blas import blas_header_version, ldflags
+from theano.tensor.nnet.abstract_conv import get_conv_output_shape
+from theano.tensor.type import TensorType
+
 
 _logger = logging.getLogger(__name__)
 
@@ -74,8 +75,8 @@ class BaseCorr3dMM(gof.OpenMPOp):
         openmp=None,
         num_groups=1,
     ):
-        super(BaseCorr3dMM, self).__init__(openmp=openmp)
-        if isinstance(border_mode, integer_types):
+        super().__init__(openmp=openmp)
+        if isinstance(border_mode, int):
             if border_mode < 0:
                 raise ValueError(
                     "invalid border_mode {}, which must be a "
@@ -156,7 +157,7 @@ class BaseCorr3dMM(gof.OpenMPOp):
     padD = property(lambda self: self.pad[2])
 
     def __str__(self):
-        return "%s{%s, %s, %s, %s}" % (
+        return "{}{{{}, {}, {}, {}}}".format(
             self.__class__.__name__,
             self.border_mode,
             str(self.subsample),
@@ -190,7 +191,7 @@ class BaseCorr3dMM(gof.OpenMPOp):
 
     def c_compile_args(self):
         compile_args = ldflags(libs=False, flags=True)
-        compile_args += super(BaseCorr3dMM, self).c_compile_args()
+        compile_args += super().c_compile_args()
         return compile_args
 
     def c_lib_dirs(self):
@@ -201,7 +202,7 @@ class BaseCorr3dMM(gof.OpenMPOp):
 
     def c_headers(self):
         headers = ["<stdio.h>"]
-        headers += super(BaseCorr3dMM, self).c_headers()
+        headers += super().c_headers()
         return headers
 
     def c_code_cache_version(self):
@@ -647,7 +648,7 @@ class Corr3dMM(BaseCorr3dMM):
     def c_code(self, node, nodename, inp, out_, sub):
         bottom, weights = inp
         (top,) = out_
-        return super(Corr3dMM, self).c_code_helper(bottom, weights, top, sub)
+        return super().c_code_helper(bottom, weights, top, sub)
 
     def grad(self, inp, grads):
         bottom, weights = inp
@@ -761,9 +762,7 @@ class Corr3dMMGradWeights(BaseCorr3dMM):
         bottom, top = inp[:2]
         height, width, depth = inp[2:] or (None, None, None)
         (weights,) = out_
-        return super(Corr3dMMGradWeights, self).c_code_helper(
-            bottom, weights, top, sub, height, width, depth
-        )
+        return super().c_code_helper(bottom, weights, top, sub, height, width, depth)
 
     def grad(self, inp, grads):
         bottom, top = inp[:2]
@@ -897,9 +896,7 @@ class Corr3dMMGradInputs(BaseCorr3dMM):
         weights, top = inp[:2]
         height, width, depth = inp[2:] or (None, None, None)
         (bottom,) = out_
-        return super(Corr3dMMGradInputs, self).c_code_helper(
-            bottom, weights, top, sub, height, width, depth
-        )
+        return super().c_code_helper(bottom, weights, top, sub, height, width, depth)
 
     def grad(self, inp, grads):
         weights, top = inp[:2]
